@@ -82,7 +82,7 @@ typedef std::list< directory_element_type >             directory_container_type
 namespace
 {
   diskCache::Cache::Directory::timestamp_type
-  do_stat( const std::string& Path, struct stat& StatStruct );
+  do_stat( const std::string& Path, struct stat& StatStruct, bool IsRoot );
 
   const string errnoMessage( );
 
@@ -339,6 +339,7 @@ namespace diskCache
       : m_name( Path ),
         m_last_time_modified( 0 ),
         m_root( Root ),
+        is_root( ( Path.compare( Root ) == 0 ) ),
         m_state( DIRECTORY_NEW )
     {
     }
@@ -351,6 +352,10 @@ namespace diskCache
       : /* m_parent( Parent ), */
         m_name( Path ),
         m_last_time_modified( 0 ),
+        m_root( ( Parent
+                  ? Parent->Root( )
+                  : Path ) ),
+        is_root( ( Parent ) ),
         m_state( DIRECTORY_NEW )
     {
     }
@@ -366,6 +371,7 @@ namespace diskCache
         m_name( Source.m_name ),
         m_last_time_modified( Source.m_last_time_modified ),
         m_root( Source.m_root ),
+        is_root( Source.is_root ),
         m_state( Source.m_state )
     {
     }
@@ -427,7 +433,7 @@ namespace diskCache
     {
       dirref_type       retval;
 
-      static const CHAR* const method_name( "diskCache::Cache::Directory::scan( ): " );
+      static const CHAR* const caller( "diskCache::Cache::Directory::Scan( ): " );
 
       //-----------------------------------------------------------------
       //
@@ -436,63 +442,85 @@ namespace diskCache
 
       std::string       fullname( Fullname( ) );
 
-      stat_info.mod_time = do_stat( fullname, stat_info.stat_buffer );
+      stat_info.mod_time = do_stat( fullname, stat_info.stat_buffer, IsRoot( )  );
+      QUEUE_LOG_MESSAGE( "Directory::Scan: " << Fullname( )
+                         << " modified: " << ( is_updated( m_last_time_modified,
+                                                           stat_info.mod_time ) == true )
+                         ,
+                         MT_DEBUG,
+                         50,
+                         caller,
+                         "CXX" );
       if ( is_updated( m_last_time_modified,
                        stat_info.mod_time ) == true )
       {
-        //---------------------------------------------------------------
-        // Lock since it is most likely that the information will be
-        // updated.
-        // This serializes the access from the default directory scans
-        // and other methods such as HotDirectory.
-        //---------------------------------------------------------------
-        MutexLock       lock( m_scan_baton, __FILE__, __LINE__ );
-
-        stat_info.mod_time = do_stat( fullname,
-                                      stat_info.stat_buffer );
-
-        if ( is_updated( m_last_time_modified,
-                         stat_info.mod_time ) == true )
-        {
           //-------------------------------------------------------------
-          // Verify that the path is a directory
+          // Lock since it is most likely that the information will be
+          // updated.
+          // This serializes the access from the default directory scans
+          // and other methods such as HotDirectory.
           //-------------------------------------------------------------
-          if ( S_ISDIR( stat_info.stat_buffer.st_mode ) == 0 )
+          MutexLock       lock( m_scan_baton, __FILE__, __LINE__ );
+
+          stat_info.mod_time = do_stat( fullname,
+                                        stat_info.stat_buffer, IsRoot( ) );
+
+          if ( is_updated( m_last_time_modified,
+                           stat_info.mod_time ) == true )
           {
-            //-----------------------------------------------------------
-            // It is not a directory.
-            // Check if it is a symbolic link
-            //-----------------------------------------------------------
-            if ( S_ISLNK( stat_info.stat_buffer.st_mode ) )
-            {
               //---------------------------------------------------------
-              // Any entry that is a symbolic link is an error
+              // Verify that the path is a directory
               //---------------------------------------------------------
-              throw SymbolicLinkError( m_name, method_name );
-            }
-            else
-            {
-              //---------------------------------------------------------
-              // It is something other than a directory or a symbolic
-              // link.
-              //---------------------------------------------------------
-              if ( m_name.size( ) == m_root.size( ) )
+              if ( S_ISDIR( stat_info.stat_buffer.st_mode ) == 0 )
               {
-                throw StartIsNotADirectoryError( m_name, method_name );
+                  //-----------------------------------------------------
+                  // It is not a directory.
+                  // Check if it is a symbolic link
+                  //-----------------------------------------------------
+                  if ( S_ISLNK( stat_info.stat_buffer.st_mode ) )
+                  {
+                      //-------------------------------------------------
+                      // Any entry that is a symbolic link is an error
+                      //-------------------------------------------------
+                      QUEUE_LOG_MESSAGE( "ERROR: " << Fullname( )
+                                         << " is a symbolic link"
+                                         ,
+                                         MT_DEBUG,
+                                         10,
+                                         caller,
+                                         "CXX" );
+                      throw SymbolicLinkError( m_name, caller );
+                  }
+                  else
+                  {
+                      //-------------------------------------------------
+                      // It is something other than a directory or a 
+                      // symbolic link.
+                      //-------------------------------------------------
+                      if ( m_name.size( ) == m_root.size( ) )
+                      {
+                          QUEUE_LOG_MESSAGE( "ERROR: " << Fullname( )
+                                             << " root is not a directory"
+                                             ,
+                                             MT_DEBUG,
+                                             10,
+                                             caller,
+                                             "CXX" );
+                          throw StartIsNotADirectoryError( m_name, caller );
+                      }
+                      return retval;
+                  }
               }
-              return retval;
-            }
-          }
-          retval = update( Results,
-                           DirectoryCollection,
-                           stat_info );
+              retval = update( Results,
+                               DirectoryCollection,
+                               stat_info );
 
-          if ( retval )
-          {
-            DirectoryCollection.OnUpdate( retval, Results );
-            Results.Log( Caller, JobInfo );
-          }
-        } // if - mutex locked
+              if ( retval )
+              {
+                  DirectoryCollection.OnUpdate( retval, Results );
+                  Results.Log( Caller, JobInfo );
+              }
+          } // if - mutex locked
       } // if
       return retval;
     } // method Directory::Scan( ScanResults& Results )
@@ -668,11 +696,25 @@ namespace diskCache
 namespace
 {
   inline diskCache::Cache::Directory::timestamp_type
-  do_stat( const std::string& Path, struct stat& StatStruct )
+  do_stat( const std::string& Path, struct stat& StatStruct, bool IsRoot )
   {
     static const CHAR* const method_name( __FILE__ "::anonymous::do_stat: " );
 
-    int err = GenericAPI::LStat( Path, StatStruct );
+    QUEUE_LOG_MESSAGE( "Entry: " << Path
+                       ,
+                       MT_DEBUG,
+                       50,
+                       method_name,
+                       "CXX" );
+    int err = 0;
+    if ( IsRoot )
+    {
+         err = GenericAPI::Stat( Path, StatStruct );
+    }
+    else
+    {
+        err = GenericAPI::LStat( Path, StatStruct );
+    }
 
     AT( "err: " << err );      
 
@@ -707,6 +749,13 @@ namespace
       /// \todo
       ///     Remove all subdirectories recursively
       //-----------------------------------------------------------------
+    QUEUE_LOG_MESSAGE( "Exit: " << Path
+                       << " Exception: " << exc
+                       ,
+                       MT_DEBUG,
+                       50,
+                       method_name,
+                       "CXX" );
       throw std::runtime_error( exc );
     }
     //-------------------------------------------------------------------
@@ -731,6 +780,12 @@ namespace
       //-----------------------------------------------------------------
       return diskCache::Cache::Directory::MODIFIED_RESET;
     }
+    QUEUE_LOG_MESSAGE( "Exit: " << Path
+                       ,
+                       MT_DEBUG,
+                       50,
+                       method_name,
+                       "CXX" );
     return StatStruct.st_mtime;
   }
 
@@ -915,7 +970,7 @@ namespace
           temp_file += *entry_cur;
           
           struct stat stat_struct;
-          do_stat( temp_file, stat_struct );
+          do_stat( temp_file, stat_struct, false );
 
           if ( S_ISLNK( stat_struct.st_mode ) )
           {
