@@ -131,11 +131,15 @@ namespace
     //-------------------------------------------------------------------
     daemon( );
 
+    virtual ~daemon( );
+
     //-------------------------------------------------------------------
     /// \brief Start the daemon thread
     //-------------------------------------------------------------------
     static void Start( );
 
+    static void Stop( );
+
 #if WORKING
     static void WaitTilIdle( );
 #endif /* WORKING */
@@ -156,6 +160,8 @@ namespace
       }
     };
 
+    bool finished;
+
     //-------------------------------------------------------------------
     /// \brief Get the next hot directory to scan.
     ///
@@ -179,6 +185,9 @@ namespace
   typedef std::map< std::string,
 		    daemon::info > hot_directory_container_type;
 
+  TaskThread*	HotDirectoryThread = (TaskThread*)NULL;
+  daemon*   	HotDirectoryTask = new daemon;
+
   //---------------------------------------------------------------------
   /// \brief Obtain lock
   ///
@@ -418,12 +427,20 @@ namespace
   //---------------------------------------------------------------------
   /// Ensure proper initialization of task.
   //---------------------------------------------------------------------
+
   daemon::
   daemon( )
+    : finished( false )
   {
     delete_on_completion( true );
   }
 
+  daemon::
+  ~daemon( )
+  {
+    HotDirectoryTask = (daemon*)NULL;
+  }
+
   //---------------------------------------------------------------------
   /// Obtain the next logical directory to scan.
   /// This routine will skip any directory that is only referenced
@@ -503,8 +520,8 @@ namespace
       //-----------------------------------------------------------------
       // Get a thread in which to run this task in the background
       //-----------------------------------------------------------------
-      TaskThread*	thread = ThreadPool::Acquire( );
-      daemon*   	task = new daemon;
+      TaskThread*	HotDirectoryThread = ThreadPool::Acquire( );
+      HotDirectoryTask = new daemon;
       //-----------------------------------------------------------------
       /// \todo Need to setup the task thread to be returned to the pool
       ///     once the task is complete.
@@ -513,11 +530,23 @@ namespace
       //-----------------------------------------------------------------
       // Add the task to the thread and get things running
       //-----------------------------------------------------------------
-      thread->AddTask( task );
+      HotDirectoryThread->AddTask( HotDirectoryTask );
       needs_to_be_started = false;
     }
   }
 
+  void daemon::
+  Stop( )
+  {
+    if ( ( HotDirectoryThread )
+	 && ( ThreadPool::Active( HotDirectoryThread ) ) )
+    {
+      HotDirectoryThread->Halt( );
+      ThreadPool::Relinquish( HotDirectoryThread );
+      HotDirectoryThread = (TaskThread*)NULL;
+    }
+  }
+
 #if WORKING
   void daemon::
   WaitTilIdle( )
@@ -538,7 +567,6 @@ namespace
   void daemon::
   operator()( )
   {
-#if WORKING || 1
     static const char* caller = "anonymous::daemon::operator()@HotDirectory.cc";
 
     //-------------------------------------------------------------------
@@ -549,7 +577,8 @@ namespace
     wakeup.tv_nsec = 0;
     nanosleep( &wakeup, NULL );
 
-    while( MemChecker::IsExiting( ) == false )
+    while( ( ! finished ) &&
+	   ( MemChecker::IsExiting( ) == false ) )
     {
       //-----------------------------------------------------------------
       // Loop over each element in the hot list
@@ -559,7 +588,7 @@ namespace
 	weak_dir_info_type 		cur;
 	shared_dir_info_type		dir;
 
-	while( 1 )
+	while( ! finished )
 	{
 	  directory_set_type*	manager;
 	  LogMessage		errors;
@@ -597,6 +626,7 @@ namespace
       //-----------------------------------------------------------------
       // Cleanup any entries that need to be removed.
       //-----------------------------------------------------------------
+      if ( ! finished )
       {
 	MutexLock	l( baton( ),
 			   __FILE__, __LINE__ );
@@ -656,11 +686,13 @@ namespace
       //-----------------------------------------------------------------
       /// Suspend for a period of time
       //-----------------------------------------------------------------
-      wakeup.tv_sec = HotDirectory::ScanInterval( );
-      wakeup.tv_nsec = 0;
-      nanosleep( &wakeup, NULL );
+      if ( ! finished )
+      {
+	wakeup.tv_sec = HotDirectory::ScanInterval( );
+	wakeup.tv_nsec = 0;
+	nanosleep( &wakeup, NULL );
+      }
     }
-#endif /* WORKING */
   }
 
 } // namespace - anonymous
@@ -755,6 +787,13 @@ namespace diskCache
       m_scan_interval = Value;
     }
 
+    void HotDirectory::
+    StopDaemon( )
+    {
+      daemon::Stop( );
+      Reset( );
+    }
+
     //---------------------------------------------------------------------
     /// Remove a directory from the list of hot directories.
     //---------------------------------------------------------------------
