@@ -1610,6 +1610,9 @@ namespace diskCache
     bool SDGTx::
     IsMatch( DirectoryScanData& Data )
     {
+      static const char func_name[]
+	= "SDGTx::IsMatch";
+
       RegexMatch	match( SDGTx_MATCH_SIZE );
       bool retval( false );
 
@@ -1653,24 +1656,38 @@ namespace diskCache
       DirectoryScanData::searches_data_type::const_iterator
 	old_pos( Data.s_old_searches_data.find( REGISTRY_ID ) );
 
-      if ( old_pos != Data.s_old_searches_data.end( ) )
+      try
       {
-	DirectoryInfo* di( reinterpret_cast< DirectoryInfo* >( old_pos->second.get( ) ) );
+	if ( old_pos != Data.s_old_searches_data.end( ) )
+	{
+	  DirectoryInfo* di( reinterpret_cast< DirectoryInfo* >( old_pos->second.get( ) ) );
 
 	
-	if ( di->FindFile( ext, ifo, description, start, dt ) )
+	  if ( di->FindFile( ext, ifo, description, start, dt ) )
+	  {
+	    //-----------------------------------------------------------
+	    // This file previously existed, so we can trust that it has
+	    // been previously verified.
+	    //-----------------------------------------------------------
+	    sd->AddOldFile( ext, ifo, description, start, dt );
+	    is_new = false;
+	  }
+	}
+	if ( is_new )
 	{
-	  //-------------------------------------------------------------
-	  // This file previously existed, so we can trust that it has
-	  // been previously verified.
-	  //-------------------------------------------------------------
-	  sd->AddOldFile( ext, ifo, description, start, dt );
-	  is_new = false;
+	  sd->AddNewFile( ext, ifo, description, start, dt );
 	}
       }
-      if ( is_new )
+      catch( const DirectoryInfo::OverlappingFileError& Exception )
       {
-	sd->AddNewFile( ext, ifo, description, start, dt );
+	//---------------------------------------------------------------
+	// Report the error in the log file and continue.
+	//---------------------------------------------------------------
+	queueLogEntry( Exception.what( ),
+		       GenericAPI::LogEntryGroup_type::MT_ORANGE,
+		       0,
+		       func_name,
+		       "SCAN_MOUNTPT" );
       }
 
       return retval;
