@@ -198,10 +198,8 @@ namespace diskCache
   bool DumpCacheDaemon::m_io_dummy_var = false;
 
   DumpCacheDaemon::
-  DumpCacheDaemon( std::ostream* Stream )
-#if 0
-    : m_stream( Stream )
-#endif /* 0 */
+  DumpCacheDaemon( )
+    : active( true )
   {
     delete_on_completion( true );
   }
@@ -221,7 +219,8 @@ namespace diskCache
     // Dump while the application is running.
     //-------------------------------------------------------------------
     DumpTask::CriticalSection( true );
-    while( MemChecker::IsExiting( ) == false )
+    while( ( is_active( ) )
+	   && ( MemChecker::IsExiting( ) == false ) )
     {
       const bool	first_pass( MountPointScanner::FirstScanComplete( ) == false );
       bool		output_files( false );
@@ -286,8 +285,16 @@ namespace diskCache
 	  DumpTask::Wait( );
 	}
       }
-      if ( MemChecker::IsExiting( ) )
+      //-----------------------------------------------------------------
+      // Check if there is a request to halt.
+      //-----------------------------------------------------------------
+      if ( ! ( is_active( ) )
+	   || ( MemChecker::IsExiting( ) ) )
       {
+	//---------------------------------------------------------------
+	// Release critical resources
+	//---------------------------------------------------------------
+	DumpTask::CriticalSection( false );
 	break;
       }
       //-----------------------------------------------------------------
