@@ -1,5 +1,7 @@
 #include <ldas_tools_config.h>
 
+#include <sys/select.h>
+
 #include <ctype.h>
 
 #include <algorithm>
@@ -7,12 +9,16 @@
 #include "ldastoolsal/SignalHandler.hh"
 
 #include "genericAPI/Logging.hh"
+#include "genericAPI/LDASplatform.hh"
 #include "genericAPI/MonitorMemory.hh"
+#include "genericAPI/Stat.hh"
 
 #include "diskcacheAPI/Cache/ExcludedDirectoriesSingleton.hh"
 
+#include "diskcacheAPI/IO.hh"
 #include "diskcacheAPI/MetaCommands.hh"
 
+
 #include "Commands.hh"
 #include "diskcachecmd.hh"
 #include "DumpCacheDaemon.hh"
@@ -128,15 +134,35 @@ namespace diskCache
 	}
 	else if ( Key.compare( "LOG" ) == 0 )
 	{
-	  command.set_log( Value );
+	  GenericAPI::LDASplatform::AppName( Value );
 	}
 	else if ( Key.compare( "LOG_DIRECTORY" ) == 0 )
 	{
-	  command.set_log_directory( Value );
+	  GenericAPI::LoggingInfo::LogDirectory( Value );
+	}
+	else if ( Key.compare( "LOG_ARCHIVE_DIRECTORY" ) == 0 )
+	{
+	  GenericAPI::LoggingInfo::ArchiveDirectory( Value );
+	}
+	else if ( Key.compare( "LOG_DEBUG_LEVEL" ) == 0 )
+	{
+	  int	debug_level;
+	  std::istringstream	dbg_level_stream( Value );
+
+	  dbg_level_stream >> debug_level;
+	  GenericAPI::LoggingInfo::DebugLevel( debug_level );
+	}
+	else if ( Key.compare( "LOG_FORMAT" ) == 0 )
+	{
+	  GenericAPI::LoggingInfo::Format( Value );
 	}
 	else if ( Key.compare( "LOG_ROTATE_ENTRY_COUNT" ) == 0 )
 	{
-	  command.set_log_rotate_entry_count( Value );
+	  int			v;
+	  std::istringstream	s( Value );
+
+	  s >> v;
+	  GenericAPI::LoggingInfo::RotationCount( v );
 	}
 	else if ( Key.compare( "OUTPUT_ASCII" ) == 0 )
 	{
@@ -158,6 +184,14 @@ namespace diskCache
 	{
 	  command.set_scan_interval( Value );
 	}
+	else if ( Key.compare( "SERVER_PORT" ) == 0 )
+	{
+	  command.set_server_port( Value );
+	}
+	else if ( Key.compare( "STAT_TIMEOUT" ) == 0 )
+	{
+	  command.set_stat_timeout( Value );
+	}
 	else
 	{
 	  if ( state == BLOCK_DAEMON )
@@ -271,23 +305,11 @@ namespace diskCache
 			  "Number of milliseconds to pause between scans.",
 			  "integer" ) );
 
-      retval.Add( Option( OPT_LOG,
-			  "log",
+      retval.Add( Option( OPT_STAT_TIMEOUT,
+			  "stat-timeout",
 			  Option::ARG_REQUIRED,
-			  "Specify where the log messages should be written.",
-			  "filename" ) );
-
-      retval.Add( Option( OPT_LOG_DIRECTORY,
-			  "log-directory",
-			  Option::ARG_REQUIRED,
-			  "Specify the directory to capture logging information",
-			  "directory" ) );
-
-      retval.Add( Option( OPT_LOG_ROTATE_ENTRY_COUNT,
-			  "log-rotate-entry-count",
-			  Option::ARG_REQUIRED,
-			  "Specify the point at which to rotate the log files.",
-			  "count" ) );
+			  "Number of seconds to wait for system stat call to return.",
+			  "integer" ) );
 
       retval.Add( Option( OPT_MOUNT_POINTS,
 			  "mount-points",
@@ -327,14 +349,16 @@ namespace diskCache
     Daemon::
     Daemon( CommandLineOptions& Args,
 	    const ClientServerInterface::ServerInfo& Server,
-	    const std::string& DefaultConfigurationFilename )
+	    const std::string& DefaultConfigurationFilename,
+	    bool Seedable )
       : m_args( Args ),
 	m_concurrency( 4 ),
-	log_rotate_entry_count( 800 ),
 	scan_interval( 16000 ),
+	stat_timeout( 5 ),
 	version_ascii( Streams::Interface::VERSION_NONE ),
 	version_binary( Streams::Interface::VERSION_NONE ),
 	finished( false ),
+	reset_requested( false ),
 	server_info( Server )
     {
       {
@@ -430,14 +454,8 @@ namespace diskCache
 	  case OPT_SCAN_INTERVAL:
 	    set_scan_interval( arg_value );
 	    break;
-	  case OPT_LOG:
-	    set_log( arg_value );
-	    break;
-	  case OPT_LOG_DIRECTORY:
-	    set_log_directory( arg_value );
-	    break;
-	  case OPT_LOG_ROTATE_ENTRY_COUNT:
-	    set_log_rotate_entry_count( arg_value );
+	  case OPT_STAT_TIMEOUT:
+	    set_stat_timeout( arg_value );
 	    break;
 	  case OPT_MOUNT_POINTS:
 	    {
@@ -474,22 +492,23 @@ namespace diskCache
 	  }
 	}
       }
-
-      GenericAPI::LogFormatter( )->EntriesMax( log_rotate_entry_count );
+      setup_variables( );
+      if ( ( Seedable )
+	   && ( output_binary.empty( ) == false ) )
       {
-	using GenericAPI::Log::LDAS;
+	//---------------------------------------------------------------
+	// Seed the cache with previous binary
+	//---------------------------------------------------------------
+	try
+	{
+	  LDASTools::AL::ifstream	ifs( output_binary.c_str( ) );
+	  diskCache::Streams::IBinary	stream( ifs );
 
-	LDAS::stream_file_type
-	  fs( LDASTools::AL::DynamicPointerCast< LDAS::stream_file_type::element_type >
-	      ( GenericAPI::LogFormatter( )->Stream( ) ) );
-	if ( fs )
+	  diskCache::Read( stream );
+	  ifs.close( );
+	}
+	catch( ... )
 	{
-	  std::string	ad;
-	  GenericAPI::Symbols::LDAS_ARCHIVE_DIR::Get( ad );
-	  
-	  fs->ArchiveDirectory( ad );
-	  fs->FilenamePattern( "diskcache" );
-	  fs->FilenameExtension( GenericAPI::LogFormatter( )->FileExtension( ) );
 	}
       }
     }
@@ -503,6 +522,7 @@ namespace diskCache
       //-----------------------------------------------------------------
       // Remove the daemon from the list of signal handlers
       //-----------------------------------------------------------------
+      ResetOnSignal( false );
     }
 
     //-------------------------------------------------------------------
@@ -539,7 +559,11 @@ namespace diskCache
 	//---------------------------------------------------------------
 	// Start the process of resetting
 	//---------------------------------------------------------------
+#if WORKING
 	reset( );
+#else
+	reset_requested = true;
+#endif /* WORKING */
       }
     }
 
@@ -548,27 +572,57 @@ namespace diskCache
     {
       static const char* method_name = "diskCache::MetaCommand::Daemon::do_client_request";
 
+      if ( reset_requested )
+      {
+	reset( );
+      }
       if ( server->good( ) )
       {
-	queueLogEntry( "Server: waiting for client request",
-		       GenericAPI::LogEntryGroup_type::MT_DEBUG,
-		       30,
-		       method_name,
-		       "CXX" );
-	client = server->accept( );
-
-	if ( client->good( ) )
+	try
 	{
-	  Spawn( );
-	  Join( );
-	}
+	  fd_set		sset;
+	  struct timespec	timeout;
 
-	queueLogEntry( "Server: client request completed",
-		       GenericAPI::LogEntryGroup_type::MT_DEBUG,
-		       30,
-		       method_name,
-		       "CXX" );
-	client.reset( ( server_responce_type::element_type* )NULL );
+	  timeout.tv_sec = 1;
+	  timeout.tv_nsec = 0;
+
+	  FD_ZERO( &sset );
+	  FD_SET( server->handle( ), &sset );
+	  
+	  int stat = pselect( server->handle( ) + 1,
+			      &sset, (fd_set*)NULL, (fd_set*)NULL,
+			      &timeout, (const sigset_t*)NULL );
+
+	  if ( stat < 0 )
+	  {
+	    return;
+	  }
+	  if ( FD_ISSET( server->handle( ), &sset ) )
+	  {
+	    queueLogEntry( "Server: waiting for client request",
+			   GenericAPI::LogEntryGroup_type::MT_DEBUG,
+			   30,
+			   method_name,
+			   "CXX" );
+	    client = server->accept( );
+
+	    if ( client->good( ) )
+	    {
+	      Spawn( );
+	      Join( );
+	    }
+
+	    queueLogEntry( "Server: client request completed",
+			   GenericAPI::LogEntryGroup_type::MT_DEBUG,
+			   30,
+			   method_name,
+			   "CXX" );
+	    client.reset( ( server_responce_type::element_type* )NULL );
+	  }
+	}
+	catch(...)
+	{
+	}
       }
     }
 
@@ -649,6 +703,24 @@ namespace diskCache
       return retval;
     }
 
+    inline void Daemon::
+    push_excluded_directory( const std::string& Directory )
+    {
+      excluded_directories.push_back( Directory );
+    }
+    
+    inline void Daemon::
+    push_extension( const std::string& Extension )
+    {
+      m_extensions.push_back( Extension );
+    }
+    
+    inline void Daemon::
+    push_mount_point( const std::string& MountPoint )
+    {
+      m_mount_points.push_back( MountPoint );
+    }
+
     bool Daemon::
     read_command( char* Buffer, size_t BufferSize )
     {
@@ -665,6 +737,94 @@ namespace diskCache
       return retval;
     }
 
+    inline void Daemon::
+    set_concurrency( const std::string& Value )
+    {
+      std::istringstream	s( Value );
+
+      s >> m_concurrency;
+    }
+
+    inline void Daemon::
+    set_scan_interval( const std::string& Value )
+    {
+      std::istringstream	s( Value );
+
+      s >> scan_interval;
+    }
+
+    inline void Daemon::
+    set_stat_timeout( const std::string& Value )
+    {
+      std::istringstream	s( Value );
+
+      s >> stat_timeout;
+    }
+
+    inline void Daemon::
+    set_output_ascii( const std::string& Value )
+    {
+      output_ascii = Value;
+    }
+
+    inline void Daemon::
+    set_output_ascii_version( const std::string& Value )
+    {
+
+      if ( Value.substr( 0, 2 ).compare( "0x" ) == 0 )
+      {
+	std::istringstream	s( Value.substr( 2 ) );
+	s >> std::hex >> version_ascii;
+      }
+      else if ( Value[0] == '0' )
+      {
+	std::istringstream	s( Value.substr( 1 ) );
+	s >> std::oct >> version_ascii;
+      }
+      else
+      {
+	std::istringstream	s( Value );
+	s >> std::hex >> version_ascii;
+      }
+    }
+
+    inline void Daemon::
+    set_output_binary( const std::string& Value )
+    {
+      output_binary = Value;
+    }
+
+    inline void Daemon::
+    set_output_binary_version( const std::string& Value )
+    {
+      if ( Value.substr( 0, 2 ).compare( "0x" ) == 0 )
+      {
+	std::istringstream	s( Value.substr( 2 ) );
+	s >> std::hex >> version_binary;
+      }
+      else if ( Value[0] == '0' )
+      {
+	std::istringstream	s( Value.substr( 1 ) );
+	s >> std::oct >> version_binary;
+      }
+      else
+      {
+	std::istringstream	s( Value );
+	s >> std::hex >> version_binary;
+      }
+    }
+
+    inline void Daemon::
+    set_server_port( const std::string& Value )
+    {
+      std::istringstream	s( Value );
+
+      ClientServerInterface::ServerInfo::port_type	p;
+      s >> p;
+
+      const_cast< ClientServerInterface::ServerInfo& >( server_info ).Port( p );
+    }
+
     void Daemon::
     operator()( )
     {
@@ -673,20 +833,8 @@ namespace diskCache
       //-----------------------------------------------------------------
       daemon_mode = true;
 
-      //-----------------------------------------------------------------
-      // Setup the logging stream
-      //-----------------------------------------------------------------
-      std::ofstream	log_stream_base;
-      std::ostream*	log_stream = &std::cout;
-
-      if ( m_log.empty( ) == false )
-      {
-	log_stream_base.open( m_log.c_str( ) );
-	if ( log_stream_base.is_open( ) )
-	{
-	  log_stream = &log_stream_base;
-	}
-      }
+      ScanMountPointListContinuously( );
+      DumpCacheDaemonStart( );
 
       //-----------------------------------------------------------------
       // Check to see if the server port has been requested
@@ -696,35 +844,10 @@ namespace diskCache
 	server = server_type( new server_type::element_type( ) );
 	if ( server )
 	{
-	  using LDASTools::AL::SharedPtr;
-	  using GenericAPI::Status::MonitorMemory;
-	  using GenericAPI::Status::Recorder;
-
-	  //-------------------------------------------------------------
-	  // Setup monitoring of memory resources
-	  //-------------------------------------------------------------
-	  SharedPtr< MonitorMemory >
-	    mm( new MonitorMemory( MonitorMemory::MEMORY_VIRTUAL ) );
-
-	  mm->AddDataQueue( 300, 12 * 24 ); 	// Five minutes for 24 hours
-	  mm->AddDataQueue( 1800, 48 );		// 30 minutes for 24 hours
-	  mm->AddDataQueue( 3600, 24 );		// hour for 24 hours
-	  mm->AddDataQueue( 24 * 3600, 30 );	// day for a month
-
-	  Recorder::Add( mm );
-
-	  //-------------------------------------------------------------
-	  // Establish listening port
-	  //-------------------------------------------------------------
 	  server->open( server_info.Port( ) );
 	}
       }
 
-      setup_variables( ~0 );
-
-      ScanMountPointListContinuously( log_stream );
-      DumpCacheDaemonStart( log_stream );
-
       //-----------------------------------------------------------------
       // Read commands to be executed.
       //-----------------------------------------------------------------
@@ -741,26 +864,20 @@ namespace diskCache
 	char	line_buffer[ 2048 ];
 
 	std::fill( line_buffer, line_buffer + sizeof( line_buffer ), '\0' );
-	while ( ( finished == false )
-		&& ( read_command( line_buffer, sizeof( line_buffer ) ) ) )
+	while ( finished == false )
 	{
-	  ;
-	  //-------------------------------------------------------------
-	  // Switch on the command specified by the user
-	  //-------------------------------------------------------------
-	  CommandLineOptions
-	    line_options( convert_line_to_options( line_buffer ) );
+	  if ( read_command( line_buffer, sizeof( line_buffer ) ) )
+	  {
+	    //-----------------------------------------------------------
+	    // Switch on the command specified by the user
+	    //-----------------------------------------------------------
+	    CommandLineOptions
+	      line_options( convert_line_to_options( line_buffer ) );
 
-	  process_cmd( line_options);
+	    process_cmd( line_options);
+	  }
 	}
       }
-      //-----------------------------------------------------------------
-      // Get read to terminate
-      //-----------------------------------------------------------------
-      if ( log_stream_base.is_open( ) )
-      {
-	log_stream_base.close( );
-      }
     }
 
     void Daemon::
@@ -804,7 +921,8 @@ namespace diskCache
 	//---------------------------------------------------------------
 	Cache::ExcludedDirectoriesSingleton::Update( excluded_directories );
       }
-      if ( Mask & VAR_EXTENSIONS )
+      if ( ( Mask & VAR_EXTENSIONS )
+	   && ( m_extensions.size( ) > 0 ) )
       {
 	//---------------------------------------------------------------
 	// Add the extensions
@@ -822,14 +940,38 @@ namespace diskCache
 	updateFileExtList( m_extensions );
       }
 
-      if ( Mask & VAR_MOUNT_POINTS )
+      if ( ( Mask & VAR_MOUNT_POINTS )
+	   && ( m_mount_points.size( ) > 0 ) )
       {
 	//---------------------------------------------------------------
 	// Add the mount points
 	//---------------------------------------------------------------
+	{
+	  std::ostringstream	msg;
+	  msg << "Adding mount points: " << m_mount_points.size( )
+	    ;
+	  queueLogEntry( msg.str( ),
+			 GenericAPI::LogEntryGroup_type::MT_NOTE,
+			 0,
+			 "Daemon::setup_variables",
+			 "CXX" );
+	}
 	MountPointManagerSingleton::UpdateResults    status;
 
 	updateMountPtList( status, m_mount_points, false );
+	{
+	  std::ostringstream	msg;
+	  msg << "Added mount points status:"
+	      << " added: " << status.s_added.size( )
+	      << " deleted: " << status.s_deleted.size( )
+	      << " errors: " << status.s_errors.size( )
+	    ;
+	  queueLogEntry( msg.str( ),
+			 GenericAPI::LogEntryGroup_type::MT_NOTE,
+			 0,
+			 "Daemon::setup_variables",
+			 "CXX" );
+	}
       }
 
       if ( Mask & VAR_CONCURRENCY )
@@ -848,6 +990,14 @@ namespace diskCache
 	diskCache::ScanMountPointsDaemon::Interval( scan_interval );
       }
 
+      if ( Mask & VAR_STAT_TIMEOUT )
+      {
+	//---------------------------------------------------------------
+	// Setup stat timeout value
+	//---------------------------------------------------------------
+	GenericAPI::SetStatTimeout( stat_timeout );
+      }
+
       //-----------------------------------------------------------------
       // Update the cache files
       //-----------------------------------------------------------------
@@ -879,11 +1029,23 @@ namespace diskCache
     void Daemon::
     reset( )
     {
+      static const char* method_name = "diskCache::MetaCommand::Daemon::reset";
+
+      reset_requested = false;
       //-----------------------------------------------------------------
       // Re-Read the configuration information
       //-----------------------------------------------------------------
       if ( ! configuration_filename.empty( ) )
       {
+	std::ostringstream	msg;
+	msg << "Rereading configuration file: "
+	    << configuration_filename
+	  ;
+	queueLogEntry( msg.str( ),
+		       GenericAPI::LogEntryGroup_type::MT_NOTE,
+		       0,
+		       method_name,
+		       "CXX" );
 	Config_		cfg( *this );
 	std::ifstream	stream( configuration_filename.c_str( ) );
       
