@@ -26,7 +26,8 @@ namespace diskCache
   //=====================================================================
   MountPointScanner::ScanResults::
   ScanResults( )
-    : m_directory_count( 0 ),
+    : m_count_baton( ),
+      m_directory_count( 0 ),
       m_file_count( 0 ),
       m_mount_point_count( 0 )
   {
@@ -219,6 +220,8 @@ namespace diskCache
   Scan( const mount_point_container_type& MountPoints,
 	ScanResults& Answer )
   {
+    static const char* caller = "MountPointScanner::Scan";
+
     //-----------------------------------------------------------
     // Start recording when the start of this action
     //-----------------------------------------------------------
@@ -231,7 +234,7 @@ namespace diskCache
 
     if ( initialized == false )
     {
-      MemChecker::Append( on_exit, "diskCache::MountPointScanner::on_exit", 200 );
+      MemChecker::Append( on_exit, "diskCache::MountPointScanner::on_exit", 200, true );
       initialized = true;
     }
     mount_point_container_type::const_iterator
@@ -250,6 +253,18 @@ namespace diskCache
 		|| ( mount_point_reset( ) ) 
 		|| ( MemChecker::IsExiting( ) == true ) ) )
       {
+	QUEUE_LOG_MESSAGE( "Stopping the scan: "
+			   << " SyncRequest::PendingRequests( ) > 0: "
+			   << ( SyncRequest::PendingRequests( ) > 0 )
+			   << " mount_point_reset( ): " 
+			   << ( mount_point_reset( ) ) 
+			   << " MemChecker::IsExiting( ) == true: "
+			   << ( MemChecker::IsExiting( ) == true )
+			   ,
+			   MT_NOTE,
+			   0,
+			   caller,
+			   "CXX" );
 	cur = last;
       }
       //---------------------------------------------------------
@@ -259,8 +274,31 @@ namespace diskCache
       while ( ( Active( ) < Concurrency( ) )
 	      && ( cur != last ) )
       {
+	{
+	  std::ostringstream	msg;
+
+	  msg << "Adding " << *cur << " to be scanned"
+	    ;
+	  GenericAPI::queueLogEntry( msg.str( ),
+				     GenericAPI::LogEntryGroup_type::MT_DEBUG,
+				     30,
+				     caller,
+				     "IDLE" );
+	}
 	start( *cur, Answer );
 	++cur; // Advance to the mount point to scan
+	{
+	  std::ostringstream	msg;
+
+	  msg << "Of the " << Concurrency( ) << " available scanners,"
+	      << " " << Active( ) << " are active"
+	    ;
+	  GenericAPI::queueLogEntry( msg.str( ),
+				     GenericAPI::LogEntryGroup_type::MT_DEBUG,
+				     30,
+				     caller,
+				     "IDLE" );
+	}
       }
       //---------------------------------------------------------
       // Wakeup once a thread has completed.
@@ -305,6 +343,11 @@ namespace diskCache
     }
     else
     {
+      QUEUE_LOG_MESSAGE( "Completed first scan through the mount point list",
+			 MT_NOTE,
+			 0,
+			 caller,
+			 "CXX" );
       FirstScanSet( true );
     }
     MountPointScanner::CriticalSection( false );
