@@ -1,8 +1,12 @@
 #include <ldas_tools_config.h>
 
+#include <set>
+
 #include "ldastoolsal/MemChecker.hh"
+#include "ldastoolsal/mutexlock.hh"
 #include "ldastoolsal/Thread.hh"
 
+#include "Cache/HotDirectory.hh"
 #include "diskcachecmd.hh"
 #include "MountPointScanner.hh"
 #include "ScanMountPointsDaemon.hh"
@@ -25,20 +29,24 @@ namespace diskCache
 
   ScanMountPointsDaemon::
   ScanMountPointsDaemon( std::ostream* Stream )
-#if 0
-    : m_stream( Stream )
-#endif /* 0 */
+    : active( true )
   {
     delete_on_completion( true );
   }
 
+  ScanMountPointsDaemon::
+  ~ScanMountPointsDaemon( )
+  {
+  }
+
   void ScanMountPointsDaemon::
   operator()( )
   {
     //---------------------------------------------------------------------------------
     // Scan as long as the application is running.
     //---------------------------------------------------------------------------------
-    while( MemChecker::IsExiting( ) == false )
+    while( ( is_active( ) )
+	   && ( MemChecker::IsExiting( ) == false ) )
     {
       //------------------------------------------------------------------------------
       // Scan through the list of mount points.
@@ -78,5 +86,8 @@ namespace diskCache
       nanosleep( &wakeup, NULL );
       Thread::Self::CancellationType( old_type, old_aux );
     }
+    //---------------------------------------------------------------------------------
+    //---------------------------------------------------------------------------------
+    Cache::HotDirectory::StopDaemon( );
   }
 }
