@@ -17,9 +17,9 @@
 #include "ldastoolsal/unordered_map.hh"
 
 #include "genericAPI/swigexception.hh"
+#include "genericAPI/LDASplatform.hh"
 #include "genericAPI/Logging.hh"
 #include "genericAPI/LogText.hh"
-#include "genericAPI/Symbols.hh"
 
 #include "diskcacheAPI/Cache/RegistrySingleton.hh"
 
@@ -75,404 +75,446 @@ void Usage( const CommandLineOptions::option_type& ProgramName,
 int
 main( int ArgC, char** ArgV )
 {
+  static const char*	caller = "main";
+
+  int	exit_code = 0;
+
   //---------------------------------------------------------------------
   // Make sure everything is ready for use
   //---------------------------------------------------------------------
   MemChecker::Trigger	gc_trigger( true );
 
-  Initialize( );
-  Thread::StackSizeDefault( 64 * 1024 );
-  {
-    diskCache::Cache::SDGTx::file_extension_container_type	ext;
-
-    ext.push_back( ".gwf" );
-
-    diskCache::Commands::updateFileExtList( ext );
-  }
-  ServerInfo	Server;
-  //---------------------------------------------------------------------
-  // Variables for logging
-  //---------------------------------------------------------------------
-  static char cwd_buffer[ 2048 ];
-  getcwd( cwd_buffer, sizeof( cwd_buffer ) / sizeof( *cwd_buffer ) );
-  std::string	cwd( cwd_buffer );
-  LDASTools::AL::Log::stream_file_type	fs( new LDASTools::AL::Log::StreamFile );
-  LDASTools::AL::Log::stream_type	s;
-
-  s = fs;
-  GenericAPI::setLogTag( "diskcache" );
-  GenericAPI::setLogOutputDirectory( cwd );
-  GenericAPI::LogFormatter( )->EntriesMax( 500 );
-  GenericAPI::LogFormatter( )->Stream( s );
-
   try
   {
-    //-------------------------------------------------------------------
-    // Collect information about the command line options
-    //-------------------------------------------------------------------
-    enum common_option_types {
-      OPT_COMMON_CACHE_FILE,
-      OPT_COMMON_LOG_DIRECTORY,
-      OPT_COMMON_LOG_DEBUG_LEVEL,
-      OPT_COMMON_HELP,
-      OPT_COMMON_HOST,
-      OPT_COMMON_PORT
-    };
+    Initialize( );
+    Thread::StackSizeDefault( 64 * 1024 );
+    {
+      diskCache::Cache::SDGTx::file_extension_container_type	ext;
 
-    CommandLineOptions	options( ArgC, ArgV );
-    OptionSet		common_options;
-    std::string		cache_filename;
+      ext.push_back( ".gwf" );
 
-    common_options.
-      Synopsis( "[common_options]"
-		" sub_command [command_options] [command_args]" );
+      diskCache::Commands::updateFileExtList( ext );
+    }
+    ServerInfo	Server;
+    //---------------------------------------------------------------------
+    // Variables for logging
+    //---------------------------------------------------------------------
+    static char cwd_buffer[ 2048 ];
+    if ( getcwd( cwd_buffer, sizeof( cwd_buffer ) / sizeof( *cwd_buffer ) ) == (char*)NULL )
+    {
+      throw std::runtime_error( "Unable to obtain the current working directory." );
+    }
 
-    common_options.
-      Summary( "This is a multi-purpose program that is intended"
-	       " to provide much information about a cache of"
-	       " file names." );
+    std::string	cwd( cwd_buffer );
+    GenericAPI::Log::stream_file_type	fs( new GenericAPI::Log::StreamFile );
+    LDASTools::AL::Log::stream_type	s;
 
-    common_options.
-      Add( Option( OPT_COMMON_CACHE_FILE,
-		   "cache-file",
-		   Option::ARG_REQUIRED,
-		   "Provide the file name of the cache file to use",
-		   "filename" ) );
-    common_options.
-      Add( Option( OPT_COMMON_LOG_DIRECTORY,
-		   "log-directory",
-		   Option::ARG_REQUIRED,
-		   "Specify the directory to capture logging information",
-		   "directory" ) );
+    s = fs;
+    fs->FilenameExtension( GenericAPI::LogFormatter( )->FileExtension( ) );
+    GenericAPI::LogFormatter( )->Stream( s );
+    GenericAPI::setLogTag( "diskcache" );
+    GenericAPI::LoggingInfo::LogDirectory( cwd );
 
-    common_options.
-      Add( Option( OPT_COMMON_LOG_DEBUG_LEVEL,
-		   "log-debug-level",
-		   Option::ARG_REQUIRED,
-		   "Specify the debugging level",
-		   "level" ) );
-
-    common_options.
-      Add( Option( OPT_COMMON_HELP,
-		   "help",
-		   Option::ARG_NONE,
-		   "Display this message" ) );
-
-    common_options.
-      Add( Option( OPT_COMMON_HOST,
-		   "host",
-		   Option::ARG_REQUIRED,
-		   "Name of the host where the server resides",
-		   "string" ) );
-
-    common_options.
-      Add( Option( OPT_COMMON_PORT,
-		   "port",
-		   Option::ARG_REQUIRED,
-		   "Port number on which to communicate",
-		   "integer" ) );
-
-    common_options.Add( Daemon::Options( ) );
-    common_options.Add( Dump::Options( ) );
-    common_options.Add( Filenames::Options( ) );
-    common_options.Add( FilenamesRDS::Options( ) );
-    common_options.Add( Intervals::Options( ) );
-    common_options.Add( MountPointStats::Options( ) );
-    common_options.Add( Scan::Options( ) );
-
-    //-------------------------------------------------------------------
-    // Parse the general arguments
-    //-------------------------------------------------------------------
     try
     {
-      std::string	arg_name;
-      std::string	arg_value;
-      bool		parsing = true;
-      std::string	log_directory;
-      int		log_dbg_level = -2;
-      bool		dump_help = false;
+      //-------------------------------------------------------------------
+      // Collect information about the command line options
+      //-------------------------------------------------------------------
+      enum common_option_types {
+	OPT_COMMON_CACHE_FILE,
+	OPT_COMMON_LOG,
+	OPT_COMMON_LOG_DIRECTORY,
+	OPT_COMMON_LOG_ARCHIVE_DIRECTORY,
+	OPT_COMMON_LOG_DEBUG_LEVEL,
+	OPT_COMMON_LOG_FORMAT,
+	OPT_COMMON_LOG_ROTATE_ENTRY_COUNT,
+	OPT_COMMON_HELP,
+	OPT_COMMON_HOST,
+	OPT_COMMON_PORT
+      };
 
-      while( parsing )
+      CommandLineOptions	options( ArgC, ArgV );
+      OptionSet		common_options;
+      std::string		cache_filename;
+
+      common_options.
+	Synopsis( "[common_options]"
+		  " sub_command [command_options] [command_args]" );
+
+      common_options.
+	Summary( "This is a multi-purpose program that is intended"
+		 " to provide much information about a cache of"
+		 " file names." );
+
+      common_options.
+	Add( Option( OPT_COMMON_CACHE_FILE,
+		     "cache-file",
+		     Option::ARG_REQUIRED,
+		     "Provide the file name of the cache file to use",
+		     "filename" ) );
+      common_options.
+	Add( Option( OPT_COMMON_LOG,
+		     "log",
+		     Option::ARG_REQUIRED,
+		     "Specify where the log messages should be written.",
+		     "filename" ) );
+
+      common_options.
+	Add( Option( OPT_COMMON_LOG_DIRECTORY,
+		     "log-directory",
+		     Option::ARG_REQUIRED,
+		     "Specify the directory to capture logging information",
+		     "directory" ) );
+
+      common_options.
+	Add( Option( OPT_COMMON_LOG_ARCHIVE_DIRECTORY,
+		     "log-archive-directory",
+		     Option::ARG_REQUIRED,
+		     "Specify the directory to archive logging information",
+		     "directory" ) );
+
+      common_options.
+	Add( Option( OPT_COMMON_LOG_DEBUG_LEVEL,
+		     "log-debug-level",
+		     Option::ARG_REQUIRED,
+		     "Specify the debugging level",
+		     "level" ) );
+
+      common_options.
+	Add( Option( OPT_COMMON_LOG_FORMAT,
+		     "log-format",
+		     Option::ARG_REQUIRED,
+		     "Specify the output format for the logs",
+		     "<text|html>" ) );
+    
+      common_options.
+	Add( Option( OPT_COMMON_LOG_ROTATE_ENTRY_COUNT,
+		     "log-rotate-entry-count",
+		     Option::ARG_REQUIRED,
+		     "Specify the point at which to rotate the log files.",
+		     "count" ) );
+
+      common_options.
+	Add( Option( OPT_COMMON_HELP,
+		     "help",
+		     Option::ARG_NONE,
+		     "Display this message" ) );
+
+      common_options.
+	Add( Option( OPT_COMMON_HOST,
+		     "host",
+		     Option::ARG_REQUIRED,
+		     "Name of the host where the server resides",
+		     "string" ) );
+
+      common_options.
+	Add( Option( OPT_COMMON_PORT,
+		     "port",
+		     Option::ARG_REQUIRED,
+		     "Port number on which to communicate",
+		     "integer" ) );
+
+      common_options.Add( Daemon::Options( ) );
+      common_options.Add( Dump::Options( ) );
+      common_options.Add( Filenames::Options( ) );
+      common_options.Add( FilenamesRDS::Options( ) );
+      common_options.Add( Intervals::Options( ) );
+      common_options.Add( MountPointStats::Options( ) );
+      common_options.Add( Scan::Options( ) );
+
+      //-------------------------------------------------------------------
+      // Parse the general arguments
+      //-------------------------------------------------------------------
+      try
       {
-	int cmd_id
-	  = options.Parse( common_options, arg_name, arg_value );
+	std::string	arg_name;
+	std::string	arg_value;
+	bool		parsing = true;
+	bool		dump_help = false;
 
-	switch( cmd_id )
+	while( parsing )
 	{
-	case OPT_COMMON_CACHE_FILE:
-	  cache_filename = arg_value;
-	  break;
-	case OPT_COMMON_LOG_DIRECTORY:
-	  log_directory = arg_value;
-	  break;
-	case OPT_COMMON_LOG_DEBUG_LEVEL:
-	  {
-	    std::istringstream	dbg_level_stream( arg_value );
+	  int cmd_id
+	    = options.Parse( common_options, arg_name, arg_value );
 
-	    dbg_level_stream >> log_dbg_level;
-	  }
-	  break;
-	case OPT_COMMON_HELP:
-	  dump_help = true;
-	  parsing = false;
-	  break;
-	case OPT_COMMON_HOST:
+	  switch( cmd_id )
 	  {
-	    //-----------------------------------------------------------
-	    // Setup the host where the server resides
-	    //-----------------------------------------------------------
-	    Server.Hostname( arg_value );
-	  }
-	  break;
-	case OPT_COMMON_PORT:
-	  {
-	    //-----------------------------------------------------------
-	    // Setup the port where the server is listening for user
-	    // requests
-	    //-----------------------------------------------------------
-	    std::istringstream	value_stream( arg_value );
-	    ServerInfo::port_type	port;
+	  case OPT_COMMON_CACHE_FILE:
+	    cache_filename = arg_value;
+	    break;
+	  case OPT_COMMON_LOG:
+	    GenericAPI::LDASplatform::AppName( arg_value );
+	    break;
+	  case OPT_COMMON_LOG_DIRECTORY:
+	    GenericAPI::LoggingInfo::LogDirectory( arg_value );
+	    break;
+	  case OPT_COMMON_LOG_ARCHIVE_DIRECTORY:
+	    GenericAPI::LoggingInfo::ArchiveDirectory( arg_value );
+	    break;
+	  case OPT_COMMON_LOG_DEBUG_LEVEL:
+	    {
+	      int	debug_level;
+	      std::istringstream	dbg_level_stream( arg_value );
 
-	    value_stream >> port;
-	    Server.Port( port );
+	      dbg_level_stream >> debug_level;
+	      GenericAPI::LoggingInfo::DebugLevel( debug_level );
+	    }
+	    break;
+	  case OPT_COMMON_LOG_FORMAT:
+	    GenericAPI::LoggingInfo::Format( arg_value );
+	    break;
+	  case OPT_COMMON_LOG_ROTATE_ENTRY_COUNT:
+	    {
+	      int			v;
+	      std::istringstream	s( arg_value );
+
+	      s >> v;
+	      GenericAPI::LoggingInfo::RotationCount( v );
+	    }
+	    break;
+	  case OPT_COMMON_HELP:
+	    dump_help = true;
+	    parsing = false;
+	    break;
+	  case OPT_COMMON_HOST:
+	    {
+	      //-----------------------------------------------------------
+	      // Setup the host where the server resides
+	      //-----------------------------------------------------------
+	      Server.Hostname( arg_value );
+	    }
+	    break;
+	  case OPT_COMMON_PORT:
+	    {
+	      //-----------------------------------------------------------
+	      // Setup the port where the server is listening for user
+	      // requests
+	      //-----------------------------------------------------------
+	      std::istringstream	value_stream( arg_value );
+	      ServerInfo::port_type	port;
+
+	      value_stream >> port;
+	      Server.Port( port );
+	    }
+	    break;
+	  case CommandLineOptions::OPT_END_OF_OPTIONS:
+	    parsing = false;
+	    break;
 	  }
-	  break;
-	case CommandLineOptions::OPT_END_OF_OPTIONS:
-	  parsing = false;
-	  break;
 	}
-      }
-      //-----------------------------------------------------------------
-      // Check if help option was requested
-      //-----------------------------------------------------------------
-      if ( dump_help )
-      {
-	if ( options.empty( ) == false )
+	//-----------------------------------------------------------------
+	// Check if help option was requested
+	//-----------------------------------------------------------------
+	if ( dump_help )
 	{
-	  const CommandLineOptions::option_type cmd( options.Pop( ) );
+	  if ( options.empty( ) == false )
+	  {
+	    const CommandLineOptions::option_type cmd( options.Pop( ) );
 
-	  switch( CommandTable::Lookup( cmd ) )
+	    switch( CommandTable::Lookup( cmd ) )
+	    {
+	    case CommandTable::CMD_DAEMON:
+	      Usage( options.ProgramName( ), Daemon::Options( ) );
+	      break;
+	    case CommandTable::CMD_DUMP:
+	      Usage( options.ProgramName( ), Dump::Options( ) );
+	      break;
+	    case CommandTable::CMD_FILENAMES:
+	      Usage( options.ProgramName( ), Filenames::Options( ) );
+	      break;
+	    case CommandTable::CMD_FILENAMES_RDS:
+	      Usage( options.ProgramName( ), FilenamesRDS::Options( ) );
+	      break;
+	    case CommandTable::CMD_INTERVALS:
+	      Usage( options.ProgramName( ), Intervals::Options( ) );
+	      break;
+	    case CommandTable::CMD_MOUNT_POINT_STATS:
+	      Usage( options.ProgramName( ), MountPointStats::Options( ) );
+	      break;
+	    case CommandTable::CMD_SCAN:
+	      Usage( options.ProgramName( ), Scan::Options( ) );
+	      break;
+	    default:
+	      Usage( options.ProgramName( ), common_options );
+	      break;
+	    }
+	  }
+	  else
 	  {
-	  case CommandTable::CMD_DAEMON:
-	    Usage( options.ProgramName( ), Daemon::Options( ) );
-	    break;
-	  case CommandTable::CMD_DUMP:
-	    Usage( options.ProgramName( ), Dump::Options( ) );
-	    break;
-	  case CommandTable::CMD_FILENAMES:
-	    Usage( options.ProgramName( ), Filenames::Options( ) );
-	    break;
-	  case CommandTable::CMD_FILENAMES_RDS:
-	    Usage( options.ProgramName( ), FilenamesRDS::Options( ) );
-	    break;
-	  case CommandTable::CMD_INTERVALS:
-	    Usage( options.ProgramName( ), Intervals::Options( ) );
-	    break;
-	  case CommandTable::CMD_MOUNT_POINT_STATS:
-	    Usage( options.ProgramName( ), MountPointStats::Options( ) );
-	    break;
-	  case CommandTable::CMD_SCAN:
-	    Usage( options.ProgramName( ), Scan::Options( ) );
-	    break;
-	  default:
 	    Usage( options.ProgramName( ), common_options );
-	    break;
 	  }
-	}
-	else
-	{
-	  Usage( options.ProgramName( ), common_options );
-	}
-	exit( 0 );
-      }
-      //-----------------------------------------------------------------
-      // Establish debugging
-      //-----------------------------------------------------------------
-      GenericAPI::setLogOutputDirectory( log_directory );
-      {
-	if ( fs )
-	{
-	  std::string	ad;
-	  GenericAPI::Symbols::LDAS_ARCHIVE_DIR::Get( ad );
-	  
-	  fs->ArchiveDirectory( ad );
-	  fs->FilenamePattern( "diskcache" );
-	  fs->FilenameExtension( GenericAPI::LogFormatter( )->FileExtension( ) );
+	  exit( 0 );
 	}
       }
-      if ( log_dbg_level != -2 )
+      catch( ... )
       {
-	GenericAPI::setLogDebugLevel( log_dbg_level );
       }
-    }
-    catch( ... )
-    {
-    }
-    //-------------------------------------------------------------------
-    // Get the command and evaluate it.
-    //-------------------------------------------------------------------
-    if ( options.empty( ) == false )
-    {
-      //-----------------------------------------------------------------
-      // Read the cache file
-      //-----------------------------------------------------------------
-      if ( cache_filename.empty( ) == false )
+      //-------------------------------------------------------------------
+      // Get the command and evaluate it.
+      //-------------------------------------------------------------------
+      if ( options.empty( ) == false )
       {
-	//---------------------------------------------------------------
-	// Seed the  mount point manager with information from the binary
-	// stream
-	//---------------------------------------------------------------
-	LDASTools::AL::ifstream		ifs( cache_filename.c_str( ) );
-	diskCache::Streams::IBinary	stream( ifs );
-
-	diskCache::Read( stream );
-	ifs.close( );
-      }
-
-      //-----------------------------------------------------------------
-      // There is another command. Get it and take the appropriate action
-      //-----------------------------------------------------------------
-      const CommandLineOptions::option_type cmd( options.Pop( ) );
-
-      switch( CommandTable::Lookup( cmd ) )
-      {
-      case CommandTable::CMD_QUIT:
+	//-----------------------------------------------------------------
+	// Read the cache file
+	//-----------------------------------------------------------------
+	if ( cache_filename.empty( ) == false )
 	{
-	  //-------------------------------------------------------------
-	  // Quit the daemon
-	  //-------------------------------------------------------------
-	  Quit	cmd( options, Server );
+	  //---------------------------------------------------------------
+	  // Seed the  mount point manager with information from the binary
+	  // stream
+	  //---------------------------------------------------------------
+	  LDASTools::AL::ifstream		ifs( cache_filename.c_str( ) );
+	  diskCache::Streams::IBinary	stream( ifs );
 
-	  cmd( );
+	  diskCache::Read( stream );
+	  ifs.close( );
 	}
-	break;
-      case CommandTable::CMD_DAEMON:
-	{
-	  //-------------------------------------------------------------
-	  // Run as daemon
-	  //-------------------------------------------------------------
-	  std::string	cfg_filename( SYSCONFDIR );
-	  cfg_filename += "/ldas-tools.d/diskcache.cfg";
-	  Daemon	cmd( options, Server, cfg_filename );
 
-	  cmd.ResetOnSignal( true );
-	  cmd( );
-	}
-	break;
-      case CommandTable::CMD_DUMP:
-	{
-	  //-------------------------------------------------------------
-	  // Dump the current contents of the cache
-	  //-------------------------------------------------------------
-	  Dump	cmd( options, Server );
+	//-----------------------------------------------------------------
+	// There is another command. Get it and take the appropriate action
+	//-----------------------------------------------------------------
+	const CommandLineOptions::option_type cmd( options.Pop( ) );
 
-	  cmd( );
-	}
-	break;
-      case CommandTable::CMD_FILENAMES:
+	switch( CommandTable::Lookup( cmd ) )
 	{
-	  //-------------------------------------------------------------
-	  // Dump the current contents of the cache
-	  //-------------------------------------------------------------
-	  std::cerr << "INFO: Dumping filenames" << std::endl;
-	  Filenames	cmd( options, Server );
+	case CommandTable::CMD_QUIT:
+	  {
+	    //-------------------------------------------------------------
+	    // Quit the daemon
+	    //-------------------------------------------------------------
+	    Quit	cmd( options, Server );
 
-	  cmd( );
+	    cmd( );
+	  }
+	  break;
+	case CommandTable::CMD_DAEMON:
+	  {
+	    //-------------------------------------------------------------
+	    // Run as daemon
+	    //-------------------------------------------------------------
+	    std::string	cfg_filename( SYSCONFDIR );
+	    cfg_filename += "/ldas-tools.d/diskcache.cfg";
+	    Daemon	cmd( options, Server, cfg_filename,
+			     cache_filename.empty( ) );
+
+	    cmd.ResetOnSignal( true );
+	    cmd( );
+	  }
+	  break;
+	case CommandTable::CMD_DUMP:
+	  {
+	    //-------------------------------------------------------------
+	    // Dump the current contents of the cache
+	    //-------------------------------------------------------------
+	    Dump	cmd( options, Server );
+
+	    cmd( );
+	  }
+	  break;
+	case CommandTable::CMD_FILENAMES:
+	  {
+	    //-------------------------------------------------------------
+	    // Dump the current contents of the cache
+	    //-------------------------------------------------------------
+	    std::cerr << "INFO: Dumping filenames" << std::endl;
+	    Filenames	cmd( options, Server );
+
+	    cmd( );
 
 #if 0
-	  if ( cmd.IsServer( ) == false )
-	  {
-	    const Filenames::query_results_type&
-	      ans = cmd.Results( );
-	    for( Filenames::query_results_type::const_iterator
-		   cur = ans.begin( ),
-		   last = ans.end( );
-		 cur != last;
-		 ++cur )
+	    if ( cmd.IsServer( ) == false )
+	    {
+	      const Filenames::query_results_type&
+		ans = cmd.Results( );
+	      for( Filenames::query_results_type::const_iterator
+		     cur = ans.begin( ),
+		     last = ans.end( );
+		   cur != last;
+		   ++cur )
 	      {
 		std::cout << *cur << std::endl;
 	      }
-	  }
+	    }
 #endif /* 0 */
-	}
-	break;
-      case CommandTable::CMD_FILENAMES_RDS:
-	{
-	  //-------------------------------------------------------------
-	  // Dump the current contents of the cache
-	  //-------------------------------------------------------------
-	  FilenamesRDS	cmd( options, Server );
-
-	  cmd( );
-	  if ( cmd.IsServer( ) == false )
+	  }
+	  break;
+	case CommandTable::CMD_FILENAMES_RDS:
 	  {
-	    const FilenamesRDS::query_results_type&
-	      ans = cmd.Results( );
-	    for( FilenamesRDS::query_results_type::const_iterator
-		   cur = ans.begin( ),
-		   last = ans.end( );
-		 cur != last;
-		 ++cur )
+	    //-------------------------------------------------------------
+	    // Dump the current contents of the cache
+	    //-------------------------------------------------------------
+	    FilenamesRDS	cmd( options, Server );
+
+	    cmd( );
+	    if ( cmd.IsServer( ) == false )
+	    {
+	      const FilenamesRDS::query_results_type&
+		ans = cmd.Results( );
+	      for( FilenamesRDS::query_results_type::const_iterator
+		     cur = ans.begin( ),
+		     last = ans.end( );
+		   cur != last;
+		   ++cur )
 	      {
 		std::cout << *cur << std::endl;
 	      }
 		 
+	    }
 	  }
-	}
-	break;
-      case CommandTable::CMD_INTERVALS:
-	{
-	  //-------------------------------------------------------------
-	  // Dump the time range information
-	  //-------------------------------------------------------------
-	  Intervals	cmd( options, Server );
+	  break;
+	case CommandTable::CMD_INTERVALS:
+	  {
+	    //-------------------------------------------------------------
+	    // Dump the time range information
+	    //-------------------------------------------------------------
+	    Intervals	cmd( options, Server );
 
-	  cmd( );
-	}
-	break;
-      case CommandTable::CMD_MOUNT_POINT_STATS:
-	{
-	  //-------------------------------------------------------------
-	  // Dump the current contents of the cache
-	  //-------------------------------------------------------------
-	  MountPointStats	cmd( options );
+	    cmd( );
+	  }
+	  break;
+	case CommandTable::CMD_MOUNT_POINT_STATS:
+	  {
+	    //-------------------------------------------------------------
+	    // Dump the current contents of the cache
+	    //-------------------------------------------------------------
+	    MountPointStats	cmd( options );
 
-	  cmd( );
-	}
-	break;
-      case CommandTable::CMD_SCAN:
-	{
-	  //-------------------------------------------------------------
-	  // Dump the current contents of the cache
-	  //-------------------------------------------------------------
-	  Scan	cmd( options );
+	    cmd( );
+	  }
+	  break;
+	case CommandTable::CMD_SCAN:
+	  {
+	    //-------------------------------------------------------------
+	    // Dump the current contents of the cache
+	    //-------------------------------------------------------------
+	    Scan	cmd( options );
 
-	  cmd( );
-	}
-	break;
-      default:
-	{
-	  std::ostringstream	msg;
+	    cmd( );
+	  }
+	  break;
+	default:
+	  {
+	    std::ostringstream	msg;
 
-	  msg << "Unknown command: " << cmd;
+	    msg << "Unknown command: " << cmd;
 
-	  throw std::runtime_error( msg.str( ) );
+	    throw std::runtime_error( msg.str( ) );
+	  }
+	  break;
 	}
-	break;
       }
     }
-  }
-  catch( const LdasException& Exception )
-  {
-    std::ostringstream	result;
-    std::ostringstream	info;
+    catch( const LdasException& Exception )
+    {
+      std::ostringstream	result;
+      std::ostringstream	info;
 
-    if ( Exception.getSize() == 0 )
-    {
-      result << "unkown_error";
-    }
-    else
-    {
+      if ( Exception.getSize() == 0 )
+      {
+	result << "unkown_error";
+      }
+      else
+      {
         size_t index = Exception.getSize() - 1;
         
         result << Exception[ index ].getMessage();
@@ -488,61 +530,92 @@ main( int ArgC, char** ArgV )
 
         while( index != 0 )
         {
-            --index;
-            info << "\n" << Exception[ index ].getMessage();
-            if ( Exception[ index ].getInfo().size() > 0 )
-            {
-                info << ": ";
-            }
-            info << Exception[ index ].getInfo() << " [" << Exception[ index ].getFile()
-		 << ":" << Exception[ index ].getLine() << "]";
+	  --index;
+	  info << "\n" << Exception[ index ].getMessage();
+	  if ( Exception[ index ].getInfo().size() > 0 )
+	  {
+	    info << ": ";
+	  }
+	  info << Exception[ index ].getInfo() << " [" << Exception[ index ].getFile()
+	       << ":" << Exception[ index ].getLine() << "]";
         }
-    }
+      }
 
-    std::cerr << "FATAL: LDAS::Exception: "
-	      << result.str( )
-      ;
-    if ( ( info.str( ).empty( ) == false ) )
-    {
-      std::cerr << " Info: " << info.str( )
-	;
+      std::ostringstream	msg;
+
+
+      msg << "Caught a LdasException" << result.str( );
+      if ( ( info.str( ).empty( ) == false ) )
+      {
+	msg << " ( " << info.str( ) << " )"
+	  ;
+      }
+      QUEUE_LOG_MESSAGE( msg.str( ),
+			 MT_ERROR,
+			 0,
+			 caller,
+			 "CMD_DISKCACHE" );
+      exit_code = 1;
     }
-    std::cerr << std::endl
-      ;
-  }
-  catch( const SwigException& Exception )
-  {
-    std::cerr << "FATAL: "
-	      << Exception.getResult( )
-	      << " Info: " << Exception.getInfo( )
-	      << std::endl
-      ;
-  }
-  catch( const std::exception& Exception )
-  {
-    std::cerr << "FATAL: std::exception: "
-	      << Exception.what( )
-	      << std::endl
-      ;
+    catch( const SwigException& Exception )
+    {
+      QUEUE_LOG_MESSAGE( Exception.getResult( )
+			 << " ( " << Exception.getInfo( ) << " ) ",
+			 MT_ERROR,
+			 0,
+			 caller,
+			 "CMD_DISKCACHE" );
+      exit_code = 1;
+    }
+    catch( const std::exception& Exception )
+    {
+      QUEUE_LOG_MESSAGE( Exception.what( ),
+			 MT_ERROR,
+			 0,
+			 caller,
+			 "CMD_DISKCACHE" );
 #if DEAD_LOCK_DETECTOR_ENABLED
-    LDASTools::AL::DeadLockDetector::Dump( );
+      LDASTools::AL::DeadLockDetector::Dump( );
 #endif /* DEAD_LOCK_DETECTOR_ENABLED */
-    exit( 1 );
+      exit_code = 1;
+    }
+    catch( ... )
+    {
+      QUEUE_LOG_MESSAGE( "Unknown exception",
+			 MT_ERROR,
+			 0,
+			 caller,
+			 "CMD_DISKCACHE" );
+      exit_code = 1;
+    }
+    GenericAPI::SyncLog( );
+  }
+  catch( const std::exception& Exc )
+  {
+    GenericAPI::SyncLog( );
+    gc_trigger.DoGarbageCollection( );
+    std::cerr << "FATAL: exception: " << Exc.what( )
+	      << std::endl
+	      << std::flush
+      ;
+    exit_code = 98;
   }
   catch( ... )
   {
-    std::cerr << "FATAL: "
-	      << "unknown exception"
+    GenericAPI::SyncLog( );
+    gc_trigger.DoGarbageCollection( );
+    std::cerr << "FATAL: unknown exception"
 	      << std::endl
+	      << std::flush
       ;
-    exit( 1 );
+    exit_code = 99;
   }
   //---------------------------------------------------------------------
-  // Everything went as expected
+  // Leave with the appropriate exit code
   //---------------------------------------------------------------------
-  return 0;
+  GenericAPI::CloseLog( );
+  return exit_code;
 }
-
 //=======================================================================
 // CommandTable
 //=======================================================================
