@@ -37,11 +37,9 @@
 #include "diskcacheAPI/Cache/SDGTx.hh"
 
 #include "AtomicFile.hh"
-#include "DumpCacheDaemon.hh"
+#include "Daemons.hh"
 #include "DirectoryManagerSingleton.hh"
 #include "MountPointScanner.hh"
-#include "ScanMountPointsDaemon.hh"
-
 
 using std::ios_base;
 using std::istringstream;
@@ -371,6 +369,8 @@ void
 writeDirCache( const char* filename,
                diskCache::Streams::Interface::version_type Version ) 
 {
+   static const char* caller = "::writeDirCache";
+
    MountPointScanner::scanner_sync_ro_type
       scanner_sync_lock( MountPointScanner::SyncRO( ) );
 
@@ -387,8 +387,17 @@ writeDirCache( const char* filename,
 
    }
 
-   tracker.getDelta( "writeDirCache()" );   
+   REAL_4 t = tracker.getDelta( "writeDirCache()" );   
    
+   QUEUE_LOG_MESSAGE( "Wrote Binary Cache File: " << filename
+                      << " in " << int( t )
+                      << "." << std::setw( 6 ) << std::setfill( '0' ) << ( int( ( t - int( t ) ) * 10e6 ) )
+                      << " seconds"
+                      ,
+                      MT_NOTE,
+                      0,
+                      caller,
+                      "CXX" );
    return;
 }
    
@@ -405,6 +414,8 @@ void
 writeDirCacheAscii( const char* filename,
                     diskCache::Streams::Interface::version_type Version ) 
 {
+   static const char* caller = "::writeDirCacheAscii";
+
    static MutexLock::baton_type key;
    static const CHAR* const DefaultFileName( "frame_cache_dump2" );
 
@@ -426,8 +437,17 @@ writeDirCacheAscii( const char* filename,
                   ? ( diskCache::Streams::OASCII::VERSION_DEFAULT )
                   : Version );
    }
-   tracker.getDelta( "writeDirCacheAscii()" );   
+   REAL_4 t = tracker.getDelta( "writeDirCacheAscii()" );   
    
+   QUEUE_LOG_MESSAGE( "Wrote ASCII Cache File: " << filename
+                      << " in " << int( t )
+                      << "." << std::setw( 6 ) << std::setfill( '0' ) << ( int( ( t - int( t ) ) * 10e6 ) )
+                      << " seconds"
+                      ,
+                      MT_NOTE,
+                      0,
+                      caller,
+                      "CXX" );
    return;
 }
    
@@ -604,6 +624,18 @@ ScanMountPointList( MountPointScanner::ScanResults& Answer )
    //--------------------------------------------------------------------
    MountPointScanner::mount_point_container_type
       mount_points( diskCache::MountPointManagerSingleton::MountPoints( ).Var( ) );
+    {
+      std::ostringstream    msg;
+	
+      msg << "Entry: "
+	  << " Start the scan of mount points: " << mount_points.size( )
+	;
+      GenericAPI::queueLogEntry( msg.str( ),
+				 GenericAPI::LogEntryGroup_type::MT_DEBUG,
+				 30,
+				 caller,
+				 "CXX" );
+    }
 
    MountPointScanner::Scan( mount_points, Answer );
 
@@ -642,55 +674,31 @@ ScanMountPointList( MountPointScanner::ScanResults& Answer )
 //-----------------------------------------------------------------------
 /// Create an image of the cache file on the storage media.
 //----------------------------------------------------------------------
-DumpCacheDaemon::thread_type*
-DumpCacheDaemonStart( std::ostream* Stream )
+void
+DumpCacheDaemonStart( )
 {
-   using namespace diskCache;
+   diskCache::Daemon::DumpCache::Launch( );
+}
 
-   //--------------------------------------------------------------------
-   /// \todo
-   /// Protect from multiple scanner daemons from running.
-   //--------------------------------------------------------------------
-   //--------------------------------------------------------------------
-   // Get a thread in which to run this task in the background
-   //--------------------------------------------------------------------
-   DumpCacheDaemon::thread_type*        thread = ThreadPool::Acquire( );
-   DumpCacheDaemon*                     task = new DumpCacheDaemon( Stream );
-
-   //--------------------------------------------------------------------
-   /// \todo Need to setup the task thread to be returned to the pool
-   ///     once the task is complete.
-   //--------------------------------------------------------------------
-   //--------------------------------------------------------------------
-   // Add the task to the thread and get things running
-   //--------------------------------------------------------------------
-   thread->AddTask( task );
-   return thread;
+void
+DumpCacheDaemonStop( )
+{
+   diskCache::Daemon::DumpCache::Terminate( );
 }
 
 //-----------------------------------------------------------------------
 /// Scan the list of mount points in the background
 //-----------------------------------------------------------------------
 void
-ScanMountPointListContinuously( std::ostream* Stream )
+ScanMountPointListContinuously( )
 {
-   //--------------------------------------------------------------------
-   /// \todo
-   /// Protect from multiple scanner daemons from running.
-   //--------------------------------------------------------------------
-   //--------------------------------------------------------------------
-   // Get a thread in which to run this task in the background
-   //--------------------------------------------------------------------
-   TaskThread*                  thread = ThreadPool::Acquire( );
-   ScanMountPointsDaemon*       task = new ScanMountPointsDaemon( Stream );
-   //--------------------------------------------------------------------
-   /// \todo Need to setup the task thread to be returned to the pool
-   ///     once the task is complete.
-   //--------------------------------------------------------------------
-   //--------------------------------------------------------------------
-   // Add the task to the thread and get things running
-   //--------------------------------------------------------------------
-   thread->AddTask( task );
+   diskCache::Daemon::ScanMountPoints::Launch( );
+}
+
+void
+ScanMountPointListContinuouslyStop( )
+{
+   diskCache::Daemon::ScanMountPoints::Terminate( );
 }
 
 // END 
