@@ -251,7 +251,8 @@ const char* VerifyException::m_error_strings[] =
     "one of the internal frame structures does not pass its own consitancy check",
     "the file is missing the FrEndOfFile structure required by the frame specification.",
     "One or more channels have a non-zero dataValid field.",
-    "One or more pieces of the filename meta data is invalid."
+    "One or more pieces of the filename meta data is invalid.",
+    "One or more channel names have been duplicated within a frame."
   };
 
 const char* VerifyException::m_error_type_strings[] =
@@ -267,6 +268,7 @@ const char* VerifyException::m_error_type_strings[] =
     "FILE_TRUNCATION",
     "DATA_INVALID",
     "METADATA_INVALID",
+    "DUPLICATE_CHANNEL_NAME",
   };
 
 std::string VerifyException::
@@ -307,6 +309,7 @@ Verify::
 Verify( )
   : m_buffer_size( INT_8U( 0 ) ),
 
+    check_for_duplicate_channel_names( true ),
     m_check_data_valid( false ),
     m_check_expandability( true ),
     m_check_fast( false ),
@@ -687,6 +690,13 @@ operator()( IFrameStream& Stream,
 	  switch ( frame_object->GetClass ( ) )
 	  {
 	  case FrameSpec::Info::FSI_FRAME_H:
+	    {
+	      //-----------------------------------------------------------
+	      // Initialization and setup actions to take when the FrameH
+	      // structure is seen.
+	      //-----------------------------------------------------------
+	      name_cache.erase( name_cache.begin( ), name_cache.end( ) );
+	    }
 	    if ( ValidateMetadata( )
 		 && Filename.get( ) )
 	    {
@@ -834,22 +844,35 @@ operator()( IFrameStream& Stream,
 	    // Fall through so as to check Detector information
 	  case FrameSpec::Info::FSI_FR_SIM_DATA:
 	  case FrameSpec::Info::FSI_FR_PROC_DATA:
-	    if ( ValidateMetadata( )
-		 && Filename.get( )
-		 && qfo )
-
+	    if ( qfo )
 	    {
-	      VERIFY_STRING	name;
+	      if ( ValidateMetadata( )
+		   && Filename.get( ) )
 
-	      qfo->TOCQuery( TOCInfo::IC_NAME, TOCInfo::DataType( name ), &name,
-			     TOCInfo::IC_EOQ );
-
-	      if ( ( name.length( ) >= 3 ) &&
-		   ( name[ 2 ] == ':' ) )
 	      {
-		set_channel_site( name[0] );
+		VERIFY_STRING	name;
+
+		qfo->TOCQuery( TOCInfo::IC_NAME, TOCInfo::DataType( name ), &name,
+			       TOCInfo::IC_EOQ );
+
+		if ( ( name.length( ) >= 3 ) &&
+		     ( name[ 2 ] == ':' ) )
+		{
+		  set_channel_site( name[0] );
+		}
 	      }
-	    }
+	      if ( CheckForDuplicateChannelNames( ) )
+	      {
+		//---------------------------------------------------------
+		// Validate the uniqueness of the channel name
+		//---------------------------------------------------------
+		VERIFY_STRING	name;
+
+		qfo->TOCQuery( TOCInfo::IC_NAME, TOCInfo::DataType( name ), &name,
+			       TOCInfo::IC_EOQ );
+		is_unique( frame_object->GetClass ( ) , name );
+	      }
+	    } // if qfo
 	    break;
 	  }
 
@@ -1191,6 +1214,22 @@ crc_file_checksum_only( IStream& Stream, fr_header_type Header )
   return retval;
 }
 
+void Verify::
+is_unique( int ClassId, const std::string& Name )
+{
+  if ( name_cache[ Name ].find( ClassId ) != name_cache[ Name ].end( ) )
+  {
+    //-------------------------------------------------------------------
+    // Already exists so need to throw Exception
+    //-------------------------------------------------------------------
+    std::ostringstream	msg;
+
+    msg << "A channel named: " << Name << " already exists.";
+    throw VerifyException( VerifyException::DUPLICATE_CHANNEL_NAME, msg.str( ) );
+  }
+  name_cache[ Name ].insert( ClassId );
+}
+
 void Verify::
 verify_checksum( CheckSum* ExpectedCRC,
 		 CheckSum* CalculatedCRC,
