@@ -38,6 +38,12 @@ using namespace FrameCPP::Compression;
 #define AT( )
 #endif
 
+#if HAVE_TEMPLATE_MOVE
+#define MOVE_RET(a) ( std::move( a ) )
+#else /* HAVE_TEMPLATE_MOVE */
+#define MOVE_RET(a) ( a )
+#endif /* HAVE_TEMPLATE_MOVE */
+
 //-----------------------------------------------------------------------
 // Local functions and variables
 //-----------------------------------------------------------------------
@@ -1418,7 +1424,7 @@ SubFrVect( INT_4U Start, INT_4U Stop ) const
   //---------------------------------------------------------------------
   // Return the newly constructed FrVect
   //---------------------------------------------------------------------
-  return retval;
+  return MOVE_RET( retval );
 }
 
 //=======================================================================
