@@ -11,7 +11,7 @@
 #include <string>
 #include <vector>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/autoarray.hh"
 #include "ldastoolsal/CommandLineOptions.hh"
 #include "ldastoolsal/fstream.hh"
@@ -40,7 +40,7 @@
 #include "FrSample7.tcc"
 #include "FrSample8.tcc"
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::AutoArray;
 using LDASTools::AL::SharedPtr;
 using LDASTools::AL::filebuf;
@@ -246,7 +246,6 @@ test_frame( int Version )
 inline void
 depart( int ExitCode )
 {
-  AtExit::Cleanup( );
   exit( ExitCode );
 }
 
@@ -409,7 +408,7 @@ CommandLine( int ArgC, char** ArgV )
     m_duration( 1 ),
     m_iterations( 1 ),
     m_start_time( GPSTime( 600000000, 0 ) ),
-    m_test_frame_mode( true ),
+    m_test_frame_mode( false ),
     m_version( FRAME_SPEC_CURRENT )
 {
   //---------------------------------------------------------------------
@@ -498,6 +497,18 @@ CommandLine( int ArgC, char** ArgV )
 		 desc.str( ),
 		 "seconds") );
 
+  //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
+  desc.str( "" );
+  desc <<
+    "Enable test frame mode"
+    " (Default: " << TestFrameMode( ) << " )"
+    ;
+  m_options.
+    Add( Option( OPT_TEST_FRAME_MODE,
+		 "test-frame-mode",
+		 Option::ARG_NONE,
+		 desc.str( ) ) );
+
   //:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
   desc.str( "" );
   desc <<
@@ -575,6 +586,11 @@ CommandLine( int ArgC, char** ArgV )
 	  StartTime( GPSTime( v, 0 ) );
 	}
 	break;
+      case OPT_TEST_FRAME_MODE:
+	{
+	  TestFrameMode( true );
+	}
+	break;
       case OPT_VERSION:
 	{
 	  std::istringstream	s( arg_value );
@@ -599,6 +615,7 @@ int
 main(int ArgC, char* ArgV[])
   try
   {
+    MemChecker::Trigger	gc_trigger( true );
     CommandLine		cl( ArgC, ArgV );
 
     if ( ( cl.empty( ) == false )
@@ -974,7 +991,6 @@ usage( char* ProgramName, int Exit )
 	    << "    one or more datatypes is generated where:"
 	    << std::endl
 	    << "        <type specifier> is the type component of the frame file name" << std::endl;
-  AtExit::Cleanup( );
   exit( Exit );
 }
 #endif /* 0 */
