@@ -17,6 +17,7 @@
 FrameCError*		ErrorCode;	/* Records the error code	*/
 const char*		ProcessName;	/* Name of the running process	*/
 int			ExitStatus = 0;	/* Exit code			*/
+int			Verbose = 0;    /* Verbose reporting of errors  */
 
 static const INT_2U FRAME_VERSION = 8;
 static const INT_4U START = 600000000;
@@ -65,6 +66,10 @@ Failed( const char* FunctionName )
 {
   if ( ErrorCode )
   {
+    if ( Verbose )
+    {
+      fprintf( stderr, "FATAL: %s: %d : %s\n", FunctionName, ErrorCode->s_errno, ErrorCode->s_message );
+    }
     ExitStatus = 1;
     return 1;
   }
