@@ -154,8 +154,7 @@ namespace
 	    res_cur = resamples.find( ChannelName );
 	 if ( res_cur == resamples.end( ) )
 	 {
-	    // This condition should never happen
-	    return;
+	    throw FrameAPI::RDS::MissingChannel( ChannelName );
 	 }
 
 	 ostringstream	r;
@@ -338,8 +337,7 @@ processChannel( fr_adc_data_type Adc )
 
    if ( r == resampling.end( ) )
    {
-      // Should never happen
-      return;
+      throw FrameAPI::RDS::MissingChannel( Adc->GetName( ) );
    }
    INT_4U	resample_factor( r->second.first );
    //--------------------------------------------------------------------
@@ -409,8 +407,7 @@ processChannel(	fr_proc_data_type Proc )
 
    if ( r == resampling.end( ) )
    {
-      // Should never happen
-      return;
+      throw FrameAPI::RDS::MissingChannel( Proc->GetName( ) );
    }
    INT_4U	resample_factor( r->second.first );
    //--------------------------------------------------------------------
@@ -493,12 +490,9 @@ createHistory( )
    gps_time.Now();
    
    ostringstream record;
-   size_t len;
 
    record << "frameAPI: resampled RDS (resample factors: ";
 
-   len = record.str( ).length( );
-
    resample_history	rh( resampling,
 			    record,
 			    getHistoryName( ),
