@@ -10,7 +10,7 @@
 #include <memory>
 #include <set>
 
-#include "ldastoolsal/AtExit.hh"
+#include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/gpstime.hh"
 #include "ldastoolsal/mutexlock.hh"
 #include "ldastoolsal/ReadWriteLock.hh"
@@ -18,7 +18,7 @@
 #include "genericAPI/Logging.hh"
 #include "genericAPI/MountPointStatus.hh"
 
-using LDASTools::AL::AtExit;
+using LDASTools::AL::MemChecker;
 using LDASTools::AL::MutexLock;
 using LDASTools::AL::ReadWriteLock;
 
@@ -331,7 +331,13 @@ Locate( std::string Path )
 
 using GenericAPI::MountPointStatus;
 
-static ReadWriteLock::baton_type	mount_points_baton;
+static ReadWriteLock::baton_type&
+mount_points_baton( )
+{
+  static ReadWriteLock::baton_type	baton;
+
+  return baton;
+}
 
 static bool				is_initialized
 = MountPointStatus::Initialize( );
@@ -367,7 +373,7 @@ namespace GenericAPI
     //-------------------------------------------------------------------
     // Modifying access
     //-------------------------------------------------------------------
-    ReadWriteLock	lock( mount_points_baton,
+    ReadWriteLock	lock( mount_points_baton( ),
 			      ReadWriteLock::WRITE,
 			      __FILE__, __LINE__ );
     //-------------------------------------------------------------------
@@ -385,9 +391,9 @@ namespace GenericAPI
   bool  MountPointStatus::
   Initialize( )
   {
-    AtExit::Append( cleanup_at_exit,
-		    "GenericAPI::MountPointStatus::cleanup_at_exit",
-		    50 );
+    MemChecker::Append( cleanup_at_exit,
+			"GenericAPI::MountPointStatus::cleanup_at_exit",
+			50 );
     pthread_atfork( fork_prepare, fork_parent, (void (*)())NULL );
     return true;
   }
@@ -404,7 +410,7 @@ namespace GenericAPI
     //-------------------------------------------------------------------
     // Checking access
     //-------------------------------------------------------------------
-    ReadWriteLock	lock( mount_points_baton,
+    ReadWriteLock	lock( mount_points_baton( ),
 			      ReadWriteLock::READ,
 			      __FILE__, __LINE__ );
     
@@ -429,7 +435,7 @@ namespace GenericAPI
     //-------------------------------------------------------------------
     // Modifying access
     //-------------------------------------------------------------------
-    ReadWriteLock	lock( mount_points_baton,
+    ReadWriteLock	lock( mount_points_baton( ),
 			      ReadWriteLock::WRITE,
 			      __FILE__, __LINE__ );
     //-------------------------------------------------------------------
@@ -457,7 +463,7 @@ namespace GenericAPI
     //-------------------------------------------------------------------
     // Modifying access
     //-------------------------------------------------------------------
-    ReadWriteLock	lock( mount_points_baton,
+    ReadWriteLock	lock( mount_points_baton( ),
 			      ReadWriteLock::WRITE,
 			      __FILE__, __LINE__ );
     
@@ -510,7 +516,7 @@ namespace GenericAPI
     //-------------------------------------------------------------------
     // Non-modifying access
     //-------------------------------------------------------------------
-    ReadWriteLock	lock( mount_points_baton,
+    ReadWriteLock	lock( mount_points_baton( ),
 			      ReadWriteLock::READ,
 			      __FILE__, __LINE__ );
     try
@@ -542,7 +548,7 @@ namespace GenericAPI
     //-------------------------------------------------------------------
     // Non-modifying access
     //-------------------------------------------------------------------
-    ReadWriteLock	lock( mount_points_baton,
+    ReadWriteLock	lock( mount_points_baton( ),
 			      ReadWriteLock::WRITE,
 			      __FILE__, __LINE__ );
     try
@@ -913,7 +919,7 @@ fork_parent( )
   //---------------------------------------------------------------------
   // Have exclusive access to the list of mount points
   //---------------------------------------------------------------------
-  ReadWriteLock	lock( mount_points_baton,
+  ReadWriteLock	lock( mount_points_baton( ),
 		      ReadWriteLock::WRITE,
 		      __FILE__, __LINE__ );
   //---------------------------------------------------------------------
@@ -955,7 +961,7 @@ fork_prepare( )
 		 caller,
 		 "CXX_THREAD" );
 
-  ReadWriteLock	lock( mount_points_baton,
+  ReadWriteLock	lock( mount_points_baton( ),
 		      ReadWriteLock::WRITE,
 		      __FILE__, __LINE__ );
   //---------------------------------------------------------------------
