@@ -9,7 +9,6 @@
 #include "ldastoolsal/MemChecker.hh"
 #include "ldastoolsal/ErrorLog.hh"
 #include "ldastoolsal/mutexlock.hh"
-#include "ldastoolsal/Pool.hh"
 #include "ldastoolsal/SystemCallTask.hh"
 #include "ldastoolsal/TaskThread.hh"
 #include "ldastoolsal/Timeout.hh"
@@ -25,7 +24,6 @@
 using LDASTools::AL::MemChecker;
 using LDASTools::AL::ErrorLog;
 using LDASTools::AL::MutexLock;
-using LDASTools::AL::Pool;
 using LDASTools::AL::SystemCallTask;
 using LDASTools::AL::TaskThread;
 using LDASTools::AL::Timeout;
@@ -85,6 +83,8 @@ namespace
 
     virtual ~lStat( );
 
+    std::ostream& Dump( std::ostream& Stream ) const;
+
     //-------------------------------------------------------------------
     /// \brief Initialize the instance for use.
     ///
@@ -122,39 +122,6 @@ namespace
 
   typedef GenericAPI::StatPoolT< lStat > SysCallStatPool_type;
 
-#if 0
-  //---------------------------------------------------------------------
-  /// \brief Collection of reusable stat buffers
-  //---------------------------------------------------------------------
-  class StatPool
-    : public Pool< value_type >
-  {
-    SINGLETON_TS_DECL( StatPool );
-  };
-#endif /* 0 */
-
-  //---------------------------------------------------------------------
-  /// \brief Collection of stat buffers that have timed out
-  ///
-  /// This is only a stop gap solution to prevent the memory resource
-  /// from being recycled while being used by another thread.
-  ///
-  /// \todo
-  ///    Instead of collecting these buffers in a pool where they will
-  ///    be leaking memory, the thread needs to take ownership of the
-  ///    object and destroy it once the thread completes.
-  //---------------------------------------------------------------------
-  class StatTrashPool
-    : public Pool< value_type >
-  {
-    SINGLETON_TS_DECL( StatTrashPool );
-  };
-
-  //---------------------------------------------------------------------
-  /// \brief Create a new instance for use in the pool
-  //---------------------------------------------------------------------
-  value_type create( );
-
   int stat_wrapper( const std::string& Path,
 		    lStat::buffer_type& StatBuffer,
 		    lStat::mode_type Mode,
@@ -183,21 +150,11 @@ namespace GenericAPI
 
       if ( initialized == false )
       {
-#if 0
-	const StatPool::info_type lstat_base = StatPool::StatType( );
-    
-	if ( ( interupt > 0 )
-	     && ( dynamic_cast< const StatDirect* >( lstat_base ) ) )
-	{
-	  wakeup( interupt );	// Initialize the signal handler
-	}
-#else
 	if ( ( interupt > 0 )
 	     && ( SysCallStatPool_type::Interuptable( ) ) )
 	{
 	  wakeup( interupt );	// Initialize the signal handler
 	}
-#endif
 	initialized = true;
       }
     }
@@ -264,6 +221,13 @@ namespace {
   {
   }
 
+  std::ostream& lStat::
+  Dump( std::ostream& Stream ) const
+  {
+    Stream << "lStat: " << m_path;
+    return Stream;
+  }
+
   //---------------------------------------------------------------------
   /// This actually does the system call.
   /// The local buffer is used to prevent memory corruuption in the
@@ -344,7 +308,7 @@ namespace {
     //-----------------------------------------------------------
     // Get entry from pool to reduce system allocation overhead
     //-----------------------------------------------------------
-    SysCallStatPool_type::info_type
+    SysCallStatPool_type::element_type
       syscall = SysCallStatPool_type::Request( );
 
     int	status = TIMEOUT_COMPLETED;
@@ -446,7 +410,7 @@ namespace {
 	// Put onto the trash heap to prevent the memory from being
 	// recycled and causing memory corruption.
 	//---------------------------------------------------------------
-	StatTrashPool::Instance( ).Relinquish( syscall );
+	SysCallStatPool_type::Trash( syscall );
       }
     }
     if ( errno == EINTR )
@@ -462,42 +426,4 @@ namespace {
     return retval;
   }
 
-#if 0
-  //---------------------------------------------------------------------
-  //---------------------------------------------------------------------
-  SINGLETON_TS_INST( StatPool );
-
-  StatPool::
-  StatPool( )
-  {
-    MemChecker::Append( singleton_suicide,
-			"<anonymous>::StatPool::singleton_suicide",
-			5 );
-  }
-#endif /* 0 */
-
-  //---------------------------------------------------------------------
-  //---------------------------------------------------------------------
-  SINGLETON_TS_INST( StatTrashPool );
-
-  StatTrashPool::
-  StatTrashPool( )
-  {
-    MemChecker::Append( singleton_suicide,
-			"<anonymous>::StatTrashPool::singleton_suicide",
-			5 );
-  }
-
-  //---------------------------------------------------------------------
-  /// This routine is used to create an new instance of the lStat
-  /// class if none are available in the pool.
-  //---------------------------------------------------------------------
-  value_type
-  create( )
-  {
-    value_type	retval( new value_type::element_type );
-
-    return retval;
-  }
-
 }
