@@ -240,14 +240,7 @@ namespace LDASTools
       {
 	Close( );
       }
-      std::ostringstream	filename;
-
-      filename << archive_directory
-	       << "/"
-	       << filename_pattern
-	       << filename_extension
-	;
-      open( filename.str( ).c_str( ) );
+      open( filename( ).c_str( ) );
       onOpen( );
     }
 
@@ -270,13 +263,15 @@ namespace LDASTools
       this->StreamInterface::operator<<( Message )
 				     << std::flush
 	;
+      rotate_bytes += Message.size( );
+      ++rotate_entries;
       //-----------------------------------------------------------------
       // Check to see if the log file should be closed.
       //-----------------------------------------------------------------
       if ( ( ( rotate_bytes_trigger )
 	     && ( rotate_bytes >= rotate_bytes_trigger ) )
-	   || ( ( rotate_entries_trigger )
-		&& ( rotate_entries >= rotate_entries_trigger ) ) )
+	   || ( ( entriesMax( ) )
+		&& ( entries( ) >= entriesMax( ) ) ) )
       {
 	Close( );
 	if ( ! IsOpen( ) )
@@ -287,6 +282,70 @@ namespace LDASTools
       }
     }
 
+
+    //---------------------------------------------------------------
+    //---------------------------------------------------------------
+    std::string Log::StreamFile::
+    archive_filename( ) const
+    {
+      struct stat	stat_buf;
+      std::string	fname( StreamFile::filename( ) );
+
+      //-----------------------------------------------------------------
+      // Figure out when the last entry was made to the log file
+      //-----------------------------------------------------------------
+      if ( ::stat( fname.c_str( ), &stat_buf ) != 0 )
+      {
+	//---------------------------------------------------------------
+	// There is an issue with getting access to the log file.
+	//---------------------------------------------------------------
+	std::ostringstream	msg;
+
+	msg << "Stat( " << fname << ", stat_buf ) failed: "
+	    << ErrnoMessage( )
+	  ;
+	throw std::runtime_error( msg.str( ) );
+      }
+
+      LDASTools::AL::GPSTime
+	log_time( stat_buf.st_mtime, 0, LDASTools::AL::GPSTime::UTC );
+
+      //-----------------------------------------------------------------
+      // Generate the filename.
+      //-----------------------------------------------------------------
+      std::ostringstream	retval;
+
+      retval << ArchiveDirectory( )
+	     << "/" << FilenamePattern( )
+	     << ".log." << log_time.GetSeconds( ) << FilenameExtension( )
+	;
+      return retval.str( );
+    }
+
+    //---------------------------------------------------------------
+    //---------------------------------------------------------------
+    INT_4U Log::StreamFile::
+    entriesMax( ) const
+    {
+      return rotate_entries_trigger;
+    }
+
+    //---------------------------------------------------------------
+    //---------------------------------------------------------------
+    std::string Log::StreamFile::
+    filename( ) const
+    {
+      std::ostringstream	filename;
+
+      //-----------------------------------------------------------------
+      // Generate the filename.
+      //-----------------------------------------------------------------
+      filename << ArchiveDirectory( )
+	       << "/" << FilenamePattern( )
+	       << ".log" << FilenameExtension( )
+	;
+      return filename.str( );
+    }
     //---------------------------------------------------------------
     //---------------------------------------------------------------
     void Log::StreamFile::
@@ -301,9 +360,6 @@ namespace LDASTools
 	  //-----------------------------------------------------------------
 	  // Write the footer and close the log
 	  //-----------------------------------------------------------------
-#if WORKING
-	  footer( );
-#endif /* WORKING */
 	  Close( );
 	}
 	//-------------------------------------------------------------------
@@ -337,51 +393,25 @@ namespace LDASTools
 	{
 	  try {
 	    ::close( fd );
-	    struct stat stat_buf;
-
-	    if ( ::stat( filename( ).c_str( ), &stat_buf ) != 0 )
-	    {
-	      //---------------------------------------------------------------
-	      // There is an issue with getting access to the log file.
-	      //---------------------------------------------------------------
-	      std::ostringstream	msg;
-
-	      msg << "Stat( " << filename( ) << ", stat_buf ) failed: "
-		  << ErrnoMessage( )
-		;
-	      throw std::runtime_error( msg.str( ) );
-
-	    }
-	    //-----------------------------------------------------------------
-	    // Generate the archive name
-	    //-----------------------------------------------------------------
-	    std::ostringstream	archive;
-	    {
-	
-	      LDASTools::AL::GPSTime		log_time( stat_buf.st_mtime, 0,
-						  LDASTools::AL::GPSTime::UTC );
-
-	      archive << archive_directory
-		      << "/" << filename_pattern << "." << log_time.GetSeconds( )
-		;
-	    }
 	    //-----------------------------------------------------------------
 	    // Archive the file
 	    //-----------------------------------------------------------------
-	    if ( ::rename( filename( ).c_str( ),
-			   archive.str( ).c_str( ) ) != 0 )
+	    std::string	fname( filename( ) );
+	    std::string aname( archive_filename( ) );
+
+	    if ( ::rename( fname.c_str( ), aname.c_str( ) ) != 0 )
 	    {
 	      //---------------------------------------------------------------
 	      // There is an issue with renaming the file
 	      //---------------------------------------------------------------
 	      std::ostringstream	msg;
 
-	      msg << "::rename( " << filename( )
-		  << ", " << archive.str( ) << " ) failed: "
+	      msg << "::rename( " << fname << ", " << aname << " ) failed: "
 		  << ErrnoMessage( )
 		;
 	      throw std::runtime_error( msg.str( ) );
 	    }
+#if WORKING
 	    //-----------------------------------------------------------------
 	    // Setup for fixing symbolic links
 	    //-----------------------------------------------------------------
@@ -407,6 +437,7 @@ namespace LDASTools
 	      /// Report error if creation of symlink failed
 	      //---------------------------------------------------------------
 	    }
+#endif /* WORKING */
 
 	  }
 	  catch( const std::exception& Error )
@@ -428,12 +459,6 @@ namespace LDASTools
 	// Open the new log
 	//-------------------------------------------------------------------
 	Open( );
-#if WORKING
-	//-------------------------------------------------------------------
-	// Write the preamble
-	//-------------------------------------------------------------------
-	header( );
-#endif /* WORKING */
       }
       catch( ... )
       {
@@ -577,6 +602,34 @@ namespace LDASTools
       return m_stream;
     }
 
+    void Log::
+    Sync( ) const
+    {
+      MutexLock	lock( m_message_baton, __FILE__, __LINE__ );
+
+      while ( ( m_output_queue.empty( ) == false )
+	      || ( m_message_queue.empty( ) == false ) )
+      {
+	//---------------------------------------------------------------
+	// Release the lock so others can manipulate the queue
+	//---------------------------------------------------------------
+	m_message_baton.Unlock( __FILE__, __LINE__ );
+	//---------------------------------------------------------------
+	// Give time for everything else to get started
+	//---------------------------------------------------------------
+	struct timespec wakeup;
+      
+	wakeup.tv_sec = WAIT_FOR_N_SECONDS;
+	wakeup.tv_nsec = 0;
+      
+	nanosleep( &wakeup, NULL );
+	//---------------------------------------------------------------
+	// Reacquire the lock so we have an accurate count
+	//---------------------------------------------------------------
+	m_message_baton.Lock( __FILE__, __LINE__ );
+      }
+    }
+
     //-------------------------------------------------------------------
     /// By default, there is no special action that needs to take place
     /// when the file is closed.
