@@ -100,11 +100,11 @@ namespace LDASTools
     {
       if ( IsCriticalSection )
       {
-	Mutex( ).pimpl_->lock( );
+	Mutex( ).Lock( __FILE__, __LINE__ );
       }
       else
       {
-	Mutex( ).pimpl_->unlock( );
+	Mutex( ).Unlock( __FILE__, __LINE__ );
       }
     }
 
