@@ -16,6 +16,7 @@
 #include "ldastoolsal/IOLock.hh"
 #include "ldastoolsal/unordered_map.hh"
 #include "ldastoolsal/ldasexception.hh"
+#include "ldastoolsal/ReadWriteLock.hh"
 #include "ldastoolsal/Thread.hh"
 #include "ldastoolsal/Singleton.hh"
 
@@ -29,6 +30,7 @@
 using LDASTools::AL::Thread;
 using LDASTools::AL::MemChecker;
 using LDASTools::AL::MutexLock;
+using LDASTools::AL::ReadWriteLock;
 using LDASTools::AL::unordered_map;
 
 namespace {
@@ -56,19 +58,16 @@ public:
   typedef Thread::thread_type::handle_type	key_type;
   typedef Thread* value_type;
 
-  static void Add( key_type, value_type );
+  static void Add( key_type Key, value_type Value );
 
-  static value_type Get( key_type );
+  static value_type Get( key_type Key );
 
-  static inline key_type Self( )
-  {
-    return pthread_self( );
-  }
+  static void Remove( key_type Key );
 
-  static void Remove( key_type );
+  static key_type Self( );
 
 private:
-  friend class Thread::Self;
+  //  friend class Thread::Self;
 
   typedef unordered_map< key_type, value_type
 #if NEED_PTHREAD_T_HASH_FUNC
@@ -76,50 +75,59 @@ private:
 #endif /* NEEDED_PTHREAD__T_HASH_FUNC */
 			 > thread_registry_type;
 
-  MutexLock::baton_type	__baton__;
-  thread_registry_type  m_storage;
+  ReadWriteLock::baton_type	baton_;
+  thread_registry_type		storage_;
 
-  static MutexLock::baton_type baton( );
+  void add( key_type Key, value_type Value );
 
-  static value_type get( key_type );
+  value_type get( key_type Key );
 
-  static thread_registry_type storage( );
-};
+  void remove( key_type Key );
+}; // class thread_registry
 
 SINGLETON_INSTANCE_DEFINITION( LDASTools::AL::SingletonHolder< ::thread_registry > )
 
 void thread_registry::
-Add( thread_registry::key_type Key, thread_registry::value_type Value )
+Add( key_type Key, value_type Value )
 {
-  MutexLock	l( baton( ),
-		   __FILE__, __LINE__ );
-
-  storage( )[ Key ] = Value;
+  Instance( ).add( Key, Value );
 }
 
 thread_registry::value_type thread_registry::
-Get( thread_registry::key_type Key )
+Get( key_type Key )
 {
-  MutexLock	l( baton( ),
-		   __FILE__, __LINE__ );
-
-  return get( Key );
+  return Instance( ).get( Key );
 }
 
 void thread_registry::
-Remove( thread_registry::key_type Key )
+Remove( key_type Key )
 {
-  MutexLock	l( baton( ),
+  Instance( ).remove( Key );
+}
+
+inline thread_registry::key_type thread_registry::
+Self( )
+{
+  return pthread_self( );
+}
+
+void thread_registry::
+add( thread_registry::key_type Key, thread_registry::value_type Value )
+{
+  ReadWriteLock	l( baton_, ReadWriteLock::WRITE,
 		   __FILE__, __LINE__ );
 
-  storage( ).erase( Key );
+  storage_[ Key ] = Value;
 }
 
 thread_registry::value_type thread_registry::
 get( thread_registry::key_type Key )
 {
-  thread_registry_type::const_iterator pos( storage( ).find( Key ) );
-  if ( pos == storage( ).end( ) )
+  ReadWriteLock	l( baton_, ReadWriteLock	::READ,
+		   __FILE__, __LINE__ );
+
+  thread_registry_type::const_iterator pos( storage_.find( Key ) );
+  if ( pos == storage_.end( ) )
   {
     std::ostringstream	msg;
     msg << "There is no managed thread with key: " << Key;
@@ -129,22 +137,28 @@ get( thread_registry::key_type Key )
   return pos->second;
 }
 
-inline thread_registry::thread_registry_type thread_registry::
-storage( )
+void thread_registry::
+remove( thread_registry::key_type Key )
 {
-  return Instance( ).m_storage;
-}
+  ReadWriteLock	l( baton_, ReadWriteLock::WRITE,
+		   __FILE__, __LINE__ );
 
-inline MutexLock::baton_type thread_registry::
-baton( )
-{
-  return Instance( ).__baton__;
+  storage_.erase( Key );
 }
 
 namespace LDASTools
 {
   namespace AL
   {
+    //-------------------------------------------------------------------
+    // Thread::thread_type class
+    //-------------------------------------------------------------------
+#ifdef constexpr
+    constexpr Thread::thread_type::handle_type
+      Thread::thread_type::NULL_THREAD
+      = (Thread::thread_type::handle_type)0;
+#endif /* constexpr */
+    
     //-------------------------------------------------------------------
     // Thread::Self class
     //-------------------------------------------------------------------
@@ -247,7 +261,14 @@ namespace LDASTools
     Thread::
     ~Thread( )
     {
-      Join( );
+      try
+      {
+        Join( );
+      }
+      catch( ... )
+      {
+	Detach( );
+      }
     }
 
 #if WORKING
