@@ -94,41 +94,56 @@ namespace LDASTools
 	  at_exit_initialized = true;
 	}
       
-#if old
-	if ( available( ).size( ) == 0 )
-	{
-	  available( ).push_front( new TaskThread );
-	}
-	in_use( ).push_front( available( ).front( ) );
-	available( ).pop_front( );
-
-	retval = in_use( ).front( );
-#else
 	if ( available( ).empty( ) == false )
 	{
+	  //-------------------------------------------------------------
+	  // Reuse
+	  //-------------------------------------------------------------
 	  in_use( ).push_front( available( ).front( ) );
 	  available( ).pop_front( );
-	  retval = in_use( ).front( );
 	}
-#endif /* old */
+	else 
+	{
+	  //-------------------------------------------------------------
+	  // Create a new instance
+	  //-------------------------------------------------------------
+	  in_use( ).push_front( new TaskThread );
+	}
+	retval = in_use( ).front( );
       }
-
-#if old
-#else
-      if ( retval == (TaskThread*)NULL )
-      {
-	retval = new TaskThread;
-
-	MutexLock	lock( baton( ),
-			      __FILE__, __LINE__ );
-	in_use( ).push_front( retval );
-      }
-
-#endif
 	
       return retval;
     }
 
+    //-------------------------------------------------------------------
+    /// Check for Resource
+    //-------------------------------------------------------------------
+    bool ThreadPool::
+    Active( TaskThread* Resource )
+    {
+      bool retval = false;
+
+      if ( Resource )
+      {
+	MutexLock lock( baton( ),
+			__FILE__, __LINE__ );
+	
+	for ( thread_container_type::const_iterator
+		cur = in_use( ).begin( ),
+		last = in_use( ).end( );
+	      cur != last;
+	      ++cur )
+	{
+	  if ( *cur == Resource )
+	  {
+	    retval = true;
+	    break;
+	  }
+	}
+      }
+      return retval;
+    }
+
     //-------------------------------------------------------------------
     /// Recyle the resource.
     //-------------------------------------------------------------------
