@@ -159,12 +159,34 @@ private:
 //=======================================================================
 //=======================================================================
 
+static void no_memory( )
+{
+  //---------------------------------------------------------------------
+  // When there is no memory left, just surrender for another day
+  // for there really is no safe action to take
+  //---------------------------------------------------------------------
+  std::cerr << "Failed to allocate memory!" << std::endl;
+  std::exit( 1 );
+}
+
+//=======================================================================
+//=======================================================================
+
 int
 main( int ArgC, char** ArgV )
 {
+  int			exit_code = 0;
   static const char*	caller = "main";
   MemChecker::Trigger	gc_trigger( true );
 
+  //---------------------------------------------------------------------
+  // Protect ourselves from memory exhaustion
+  //---------------------------------------------------------------------
+  std::set_new_handler( no_memory );
+
+  //---------------------------------------------------------------------
+  // Make sure the frameCPP library is ready for use.
+  //---------------------------------------------------------------------
   FrameCPP::Initialize( );
 
   try
@@ -172,19 +194,46 @@ main( int ArgC, char** ArgV )
     //-------------------------------------------------------------------
     // Variables for logging
     //-------------------------------------------------------------------
+    GenericAPI::SetLogFormatter( new GenericAPI::Log::Text( "" ) );
+
     static char cwd_buffer[ 2048 ];
     getcwd( cwd_buffer, sizeof( cwd_buffer ) / sizeof( *cwd_buffer ) );
     std::string	cwd( cwd_buffer );
+    GenericAPI::Log::stream_file_type	fs( new GenericAPI::Log::StreamFile );
+    LDASTools::AL::Log::stream_type	s;
 
+    s = fs;
+    fs->FilenameExtension( GenericAPI::LogFormatter( )->FileExtension( ) );
+    GenericAPI::LogFormatter( )->Stream( s );
     GenericAPI::setLogTag( "createRDS" );
-    GenericAPI::setLogOutputDirectory( cwd );
-    GenericAPI::SetLogFormatter( new GenericAPI::Log::Text( "" ) );
+    GenericAPI::LoggingInfo::LogDirectory( cwd );
 
     CommandLine		cl( ArgC, ArgV );
     ServerInterface	server;
 
     cl();
 
+    {
+      std::ostringstream	msg;
+
+      char**			a = ArgV;
+
+      msg << "Started createRDS with the following options:";
+
+      while( *a )
+      {
+	msg << " " << *a;
+	++a;
+      }
+
+      GenericAPI::queueLogEntry( msg.str( ),
+				 GenericAPI::LogEntryGroup_type::MT_OK,
+				 0,
+				 caller,
+				 "STARTUP" );
+      GenericAPI::SyncLog( );
+    }
+
     if ( cl.Filenames( ).size( ) <= 0 )
     {
       server.Server( cl.Hostname( ), cl.Port( ) );
@@ -358,29 +407,33 @@ main( int ArgC, char** ArgV )
     QUEUE_LOG_MESSAGE( " Caught SwigException:"
 		       << " Result: " << E.getResult( )
 		       << " Info: " << E.getInfo( ),
-		       MT_DEBUG,
-		       30,
+		       MT_ERROR,
+		       0,
 		       caller,
 		       "CMD_CREATE_RDS" );
+    exit_code = 1;
   }
   catch( const std::exception& E )
   {
     QUEUE_LOG_MESSAGE( " Caught exception: " << E.what( ),
-		       MT_DEBUG,
-		       30,
+		       MT_ERROR,
+		       0,
 		       caller,
 		       "CMD_CREATE_RDS" );
+    exit_code = 1;
   }
   catch( ... )
   {
     QUEUE_LOG_MESSAGE( " Caught an unknown exception",
-		       MT_DEBUG,
-		       30,
+		       MT_ERROR,
+		       0,
 		       caller,
 		       "CMD_CREATE_RDS" );
+    exit_code = 1;
   }
 
-  return 0;
+  GenericAPI::SyncLog( );
+  return exit_code;
 }
 
 //=======================================================================
@@ -560,6 +613,46 @@ CommandLine( int ArgC, char** ArgV )
 		 "iteger" ) );
   //.....................................................................
   //.....................................................................
+  options.
+    Add( Option( OPT_VERIFY_CHECKSUM_OF_FRAME,
+		 "verify-checksum-of-frame",
+		 Option::ARG_REQUIRED,
+		 "Require verification of the frame checksum.",
+		 "boolean." ) );
+  //.....................................................................
+  //.....................................................................
+  options.
+    Add( Option( OPT_VERIFY_CHECKSUM_OF_STREAM,
+		 "verify-checksum-of-stream",
+		 Option::ARG_REQUIRED,
+		 "Require verification of the stream checksum.",
+		 "boolean." ) );
+  //.....................................................................
+  //.....................................................................
+  options.
+    Add( Option( OPT_VERIFY_DATA_VALID,
+		 "verify-data-valid",
+		 Option::ARG_REQUIRED,
+		 "Require verification of the data valid field.",
+		 "boolean." ) );
+  //.....................................................................
+  //.....................................................................
+  options.
+    Add( Option( OPT_VERIFY_FILENAME_METADATA,
+		 "verify-filename-metadata",
+		 Option::ARG_REQUIRED,
+		 "Require verification of the filename metadata.",
+		 "boolean." ) );
+  //.....................................................................
+  //.....................................................................
+  options.
+    Add( Option( OPT_VERIFY_TIME_RANGE,
+		 "verify-time-range",
+		 Option::ARG_REQUIRED,
+		 "Require verification of the time range",
+		 "boolean." ) );
+  //.....................................................................
+  //.....................................................................
   options.
     Add( Option( OPT_WITHOUT_HISTORY_RECORD,
 		 "without-history-record",
@@ -720,11 +813,7 @@ operator()( )
 	{
 	  log_directory = value;
 
-	  GenericAPI::setLogOutputDirectory( log_directory );
-	  if ( log_debug_level != -2 )
-	  {
-	    GenericAPI::setLogDebugLevel( log_debug_level );
-	  }
+	  GenericAPI::LoggingInfo::LogDirectory( value );
 	}
 	break;
       case OPT_SECONDS_PER_FRAME:
