@@ -278,7 +278,7 @@ main( int ArgC, char** ArgV )
 
     getcwd( cwd_buffer, sizeof( cwd_buffer ) / sizeof( *cwd_buffer ) );
     std::string					cwd( cwd_buffer );
-    GenericAPI::setLogOutputDirectory( cwd );
+    GenericAPI::LoggingInfo::LogDirectory( cwd );
     LDASTools::AL::Log::stream_file_type	fs( new LDASTools::AL::Log::StreamFile );
     LDASTools::AL::Log::stream_type		s;
 
